#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 411
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 110
#define ALIAS_COUNT 11
#define TOKEN_COUNT 52
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 32
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 68

enum ts_symbol_identifiers {
  sym_atom = 1,
  sym_comment = 2,
  sym_integer = 3,
  sym_decimal = 4,
  sym_string = 5,
  sym_boolean = 6,
  sym_symbol = 7,
  anon_sym_LBRACK = 8,
  anon_sym_RBRACK = 9,
  anon_sym_COMMA = 10,
  anon_sym_LBRACE = 11,
  anon_sym_RBRACE = 12,
  anon_sym_LPAREN = 13,
  anon_sym_RPAREN = 14,
  anon_sym_DOT = 15,
  anon_sym_object = 16,
  anon_sym_table = 17,
  anon_sym_integer = 18,
  anon_sym_decimal = 19,
  anon_sym_time = 20,
  anon_sym_bool = 21,
  anon_sym_string = 22,
  anon_sym_list = 23,
  anon_sym_value = 24,
  anon_sym_keyset = 25,
  anon_sym_guard = 26,
  anon_sym_COLON = 27,
  anon_sym_COLON_EQ = 28,
  anon_sym_ATdoc = 29,
  anon_sym_ATmodel = 30,
  anon_sym_defproperty = 31,
  anon_sym_ATmanaged = 32,
  anon_sym_ATevent = 33,
  anon_sym_AT = 34,
  anon_sym_namespace = 35,
  anon_sym_bless = 36,
  anon_sym_defun = 37,
  anon_sym_defcap = 38,
  anon_sym_defconst = 39,
  anon_sym_defpact = 40,
  anon_sym_defschema = 41,
  anon_sym_deftable = 42,
  anon_sym_let = 43,
  anon_sym_let_STAR = 44,
  anon_sym_cond = 45,
  anon_sym_step = 46,
  anon_sym_step_DASHwith_DASHrollback = 47,
  anon_sym_use = 48,
  anon_sym_interface = 49,
  anon_sym_module = 50,
  anon_sym_implements = 51,
  sym_source_file = 52,
  sym_list = 53,
  sym_object = 54,
  sym__literal = 55,
  sym__from = 56,
  sym_s_expression = 57,
  sym_reference = 58,
  sym__parametrized_object = 59,
  sym__parametrized_list = 60,
  sym_type_identifier = 61,
  sym_type_annotation = 62,
  sym_parameter_list = 63,
  sym_parameter = 64,
  sym_schema_field_list = 65,
  sym_schema_field = 66,
  sym_pair = 67,
  sym_bind_pair = 68,
  sym__property_name = 69,
  sym__def_name = 70,
  sym__doc_or_meta = 71,
  sym_doc = 72,
  sym_model = 73,
  sym_defproperty = 74,
  sym_managed = 75,
  sym_event = 76,
  sym_meta = 77,
  sym_namespace = 78,
  sym_bless = 79,
  sym_defun = 80,
  sym_defcap = 81,
  sym_defconst = 82,
  sym_defpact = 83,
  sym_defschema = 84,
  sym_deftable = 85,
  sym_let_variable = 86,
  sym_let_bind_pair = 87,
  sym_let_binding = 88,
  sym_cond = 89,
  sym_step = 90,
  sym_step_with_rollback = 91,
  sym_use = 92,
  sym_interface = 93,
  sym_module = 94,
  sym_implements = 95,
  aux_sym_source_file_repeat1 = 96,
  aux_sym_list_repeat1 = 97,
  aux_sym_list_repeat2 = 98,
  aux_sym_object_repeat1 = 99,
  aux_sym_reference_repeat1 = 100,
  aux_sym_parameter_list_repeat1 = 101,
  aux_sym_schema_field_list_repeat1 = 102,
  aux_sym__doc_or_meta_repeat1 = 103,
  aux_sym_model_repeat1 = 104,
  aux_sym_defpact_repeat1 = 105,
  aux_sym_let_binding_repeat1 = 106,
  aux_sym_cond_repeat1 = 107,
  aux_sym_interface_repeat1 = 108,
  aux_sym_module_repeat1 = 109,
  alias_sym_def_identifier = 110,
  alias_sym_doc_string = 111,
  alias_sym_let_variable_identifier = 112,
  alias_sym_module_governance = 113,
  alias_sym_module_identifier = 114,
  alias_sym_parameter_identifier = 115,
  alias_sym_property_identifier = 116,
  alias_sym_s_expression_head = 117,
  alias_sym_schema_field_identifier = 118,
  alias_sym_table_schema = 119,
  alias_sym_type_parameter = 120,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_atom] = "atom",
  [sym_comment] = "comment",
  [sym_integer] = "integer",
  [sym_decimal] = "decimal",
  [sym_string] = "string",
  [sym_boolean] = "boolean",
  [sym_symbol] = "symbol",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_COMMA] = ",",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DOT] = ".",
  [anon_sym_object] = "object",
  [anon_sym_table] = "table",
  [anon_sym_integer] = "integer",
  [anon_sym_decimal] = "decimal",
  [anon_sym_time] = "time",
  [anon_sym_bool] = "bool",
  [anon_sym_string] = "string",
  [anon_sym_list] = "list",
  [anon_sym_value] = "value",
  [anon_sym_keyset] = "keyset",
  [anon_sym_guard] = "guard",
  [anon_sym_COLON] = ":",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_ATdoc] = "@doc",
  [anon_sym_ATmodel] = "@model",
  [anon_sym_defproperty] = "defproperty",
  [anon_sym_ATmanaged] = "@managed",
  [anon_sym_ATevent] = "@event",
  [anon_sym_AT] = "@",
  [anon_sym_namespace] = "namespace",
  [anon_sym_bless] = "bless",
  [anon_sym_defun] = "defun",
  [anon_sym_defcap] = "defcap",
  [anon_sym_defconst] = "defconst",
  [anon_sym_defpact] = "defpact",
  [anon_sym_defschema] = "defschema",
  [anon_sym_deftable] = "deftable",
  [anon_sym_let] = "let",
  [anon_sym_let_STAR] = "let*",
  [anon_sym_cond] = "cond",
  [anon_sym_step] = "step",
  [anon_sym_step_DASHwith_DASHrollback] = "step-with-rollback",
  [anon_sym_use] = "use",
  [anon_sym_interface] = "interface",
  [anon_sym_module] = "module",
  [anon_sym_implements] = "implements",
  [sym_source_file] = "source_file",
  [sym_list] = "list",
  [sym_object] = "object",
  [sym__literal] = "_literal",
  [sym__from] = "_from",
  [sym_s_expression] = "s_expression",
  [sym_reference] = "reference",
  [sym__parametrized_object] = "_parametrized_object",
  [sym__parametrized_list] = "_parametrized_list",
  [sym_type_identifier] = "type_identifier",
  [sym_type_annotation] = "type_annotation",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter] = "parameter",
  [sym_schema_field_list] = "schema_field_list",
  [sym_schema_field] = "schema_field",
  [sym_pair] = "pair",
  [sym_bind_pair] = "bind_pair",
  [sym__property_name] = "_property_name",
  [sym__def_name] = "_def_name",
  [sym__doc_or_meta] = "_doc_or_meta",
  [sym_doc] = "doc",
  [sym_model] = "model",
  [sym_defproperty] = "defproperty",
  [sym_managed] = "managed",
  [sym_event] = "event",
  [sym_meta] = "meta",
  [sym_namespace] = "namespace",
  [sym_bless] = "bless",
  [sym_defun] = "defun",
  [sym_defcap] = "defcap",
  [sym_defconst] = "defconst",
  [sym_defpact] = "defpact",
  [sym_defschema] = "defschema",
  [sym_deftable] = "deftable",
  [sym_let_variable] = "let_variable",
  [sym_let_bind_pair] = "let_bind_pair",
  [sym_let_binding] = "let_binding",
  [sym_cond] = "cond",
  [sym_step] = "step",
  [sym_step_with_rollback] = "step_with_rollback",
  [sym_use] = "use",
  [sym_interface] = "interface",
  [sym_module] = "module",
  [sym_implements] = "implements",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_list_repeat1] = "list_repeat1",
  [aux_sym_list_repeat2] = "list_repeat2",
  [aux_sym_object_repeat1] = "object_repeat1",
  [aux_sym_reference_repeat1] = "reference_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_schema_field_list_repeat1] = "schema_field_list_repeat1",
  [aux_sym__doc_or_meta_repeat1] = "_doc_or_meta_repeat1",
  [aux_sym_model_repeat1] = "model_repeat1",
  [aux_sym_defpact_repeat1] = "defpact_repeat1",
  [aux_sym_let_binding_repeat1] = "let_binding_repeat1",
  [aux_sym_cond_repeat1] = "cond_repeat1",
  [aux_sym_interface_repeat1] = "interface_repeat1",
  [aux_sym_module_repeat1] = "module_repeat1",
  [alias_sym_def_identifier] = "def_identifier",
  [alias_sym_doc_string] = "doc_string",
  [alias_sym_let_variable_identifier] = "let_variable_identifier",
  [alias_sym_module_governance] = "module_governance",
  [alias_sym_module_identifier] = "module_identifier",
  [alias_sym_parameter_identifier] = "parameter_identifier",
  [alias_sym_property_identifier] = "property_identifier",
  [alias_sym_s_expression_head] = "s_expression_head",
  [alias_sym_schema_field_identifier] = "schema_field_identifier",
  [alias_sym_table_schema] = "table_schema",
  [alias_sym_type_parameter] = "type_parameter",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_atom] = sym_atom,
  [sym_comment] = sym_comment,
  [sym_integer] = sym_integer,
  [sym_decimal] = sym_decimal,
  [sym_string] = sym_string,
  [sym_boolean] = sym_boolean,
  [sym_symbol] = sym_symbol,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_object] = anon_sym_object,
  [anon_sym_table] = anon_sym_table,
  [anon_sym_integer] = anon_sym_integer,
  [anon_sym_decimal] = anon_sym_decimal,
  [anon_sym_time] = anon_sym_time,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_list] = anon_sym_list,
  [anon_sym_value] = anon_sym_value,
  [anon_sym_keyset] = anon_sym_keyset,
  [anon_sym_guard] = anon_sym_guard,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_ATdoc] = anon_sym_ATdoc,
  [anon_sym_ATmodel] = anon_sym_ATmodel,
  [anon_sym_defproperty] = anon_sym_defproperty,
  [anon_sym_ATmanaged] = anon_sym_ATmanaged,
  [anon_sym_ATevent] = anon_sym_ATevent,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_bless] = anon_sym_bless,
  [anon_sym_defun] = anon_sym_defun,
  [anon_sym_defcap] = anon_sym_defcap,
  [anon_sym_defconst] = anon_sym_defconst,
  [anon_sym_defpact] = anon_sym_defpact,
  [anon_sym_defschema] = anon_sym_defschema,
  [anon_sym_deftable] = anon_sym_deftable,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_let_STAR] = anon_sym_let_STAR,
  [anon_sym_cond] = anon_sym_cond,
  [anon_sym_step] = anon_sym_step,
  [anon_sym_step_DASHwith_DASHrollback] = anon_sym_step_DASHwith_DASHrollback,
  [anon_sym_use] = anon_sym_use,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_implements] = anon_sym_implements,
  [sym_source_file] = sym_source_file,
  [sym_list] = sym_list,
  [sym_object] = sym_object,
  [sym__literal] = sym__literal,
  [sym__from] = sym__from,
  [sym_s_expression] = sym_s_expression,
  [sym_reference] = sym_reference,
  [sym__parametrized_object] = sym__parametrized_object,
  [sym__parametrized_list] = sym__parametrized_list,
  [sym_type_identifier] = sym_type_identifier,
  [sym_type_annotation] = sym_type_annotation,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter] = sym_parameter,
  [sym_schema_field_list] = sym_schema_field_list,
  [sym_schema_field] = sym_schema_field,
  [sym_pair] = sym_pair,
  [sym_bind_pair] = sym_bind_pair,
  [sym__property_name] = sym__property_name,
  [sym__def_name] = sym__def_name,
  [sym__doc_or_meta] = sym__doc_or_meta,
  [sym_doc] = sym_doc,
  [sym_model] = sym_model,
  [sym_defproperty] = sym_defproperty,
  [sym_managed] = sym_managed,
  [sym_event] = sym_event,
  [sym_meta] = sym_meta,
  [sym_namespace] = sym_namespace,
  [sym_bless] = sym_bless,
  [sym_defun] = sym_defun,
  [sym_defcap] = sym_defcap,
  [sym_defconst] = sym_defconst,
  [sym_defpact] = sym_defpact,
  [sym_defschema] = sym_defschema,
  [sym_deftable] = sym_deftable,
  [sym_let_variable] = sym_let_variable,
  [sym_let_bind_pair] = sym_let_bind_pair,
  [sym_let_binding] = sym_let_binding,
  [sym_cond] = sym_cond,
  [sym_step] = sym_step,
  [sym_step_with_rollback] = sym_step_with_rollback,
  [sym_use] = sym_use,
  [sym_interface] = sym_interface,
  [sym_module] = sym_module,
  [sym_implements] = sym_implements,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_list_repeat1] = aux_sym_list_repeat1,
  [aux_sym_list_repeat2] = aux_sym_list_repeat2,
  [aux_sym_object_repeat1] = aux_sym_object_repeat1,
  [aux_sym_reference_repeat1] = aux_sym_reference_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_schema_field_list_repeat1] = aux_sym_schema_field_list_repeat1,
  [aux_sym__doc_or_meta_repeat1] = aux_sym__doc_or_meta_repeat1,
  [aux_sym_model_repeat1] = aux_sym_model_repeat1,
  [aux_sym_defpact_repeat1] = aux_sym_defpact_repeat1,
  [aux_sym_let_binding_repeat1] = aux_sym_let_binding_repeat1,
  [aux_sym_cond_repeat1] = aux_sym_cond_repeat1,
  [aux_sym_interface_repeat1] = aux_sym_interface_repeat1,
  [aux_sym_module_repeat1] = aux_sym_module_repeat1,
  [alias_sym_def_identifier] = alias_sym_def_identifier,
  [alias_sym_doc_string] = alias_sym_doc_string,
  [alias_sym_let_variable_identifier] = alias_sym_let_variable_identifier,
  [alias_sym_module_governance] = alias_sym_module_governance,
  [alias_sym_module_identifier] = alias_sym_module_identifier,
  [alias_sym_parameter_identifier] = alias_sym_parameter_identifier,
  [alias_sym_property_identifier] = alias_sym_property_identifier,
  [alias_sym_s_expression_head] = alias_sym_s_expression_head,
  [alias_sym_schema_field_identifier] = alias_sym_schema_field_identifier,
  [alias_sym_table_schema] = alias_sym_table_schema,
  [alias_sym_type_parameter] = alias_sym_type_parameter,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_symbol] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_object] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_table] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_integer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_decimal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_time] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_list] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_value] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_keyset] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_guard] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATdoc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATmodel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defproperty] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATmanaged] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATevent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bless] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defun] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defcap] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defconst] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defpact] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defschema] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_deftable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cond] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_step] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_step_DASHwith_DASHrollback] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_use] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_list] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym__from] = {
    .visible = false,
    .named = true,
  },
  [sym_s_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_reference] = {
    .visible = true,
    .named = true,
  },
  [sym__parametrized_object] = {
    .visible = false,
    .named = true,
  },
  [sym__parametrized_list] = {
    .visible = false,
    .named = true,
  },
  [sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_field_list] = {
    .visible = true,
    .named = true,
  },
  [sym_schema_field] = {
    .visible = true,
    .named = true,
  },
  [sym_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_bind_pair] = {
    .visible = true,
    .named = true,
  },
  [sym__property_name] = {
    .visible = false,
    .named = true,
  },
  [sym__def_name] = {
    .visible = false,
    .named = true,
  },
  [sym__doc_or_meta] = {
    .visible = false,
    .named = true,
  },
  [sym_doc] = {
    .visible = true,
    .named = true,
  },
  [sym_model] = {
    .visible = true,
    .named = true,
  },
  [sym_defproperty] = {
    .visible = true,
    .named = true,
  },
  [sym_managed] = {
    .visible = true,
    .named = true,
  },
  [sym_event] = {
    .visible = true,
    .named = true,
  },
  [sym_meta] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_bless] = {
    .visible = true,
    .named = true,
  },
  [sym_defun] = {
    .visible = true,
    .named = true,
  },
  [sym_defcap] = {
    .visible = true,
    .named = true,
  },
  [sym_defconst] = {
    .visible = true,
    .named = true,
  },
  [sym_defpact] = {
    .visible = true,
    .named = true,
  },
  [sym_defschema] = {
    .visible = true,
    .named = true,
  },
  [sym_deftable] = {
    .visible = true,
    .named = true,
  },
  [sym_let_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_let_bind_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_let_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_cond] = {
    .visible = true,
    .named = true,
  },
  [sym_step] = {
    .visible = true,
    .named = true,
  },
  [sym_step_with_rollback] = {
    .visible = true,
    .named = true,
  },
  [sym_use] = {
    .visible = true,
    .named = true,
  },
  [sym_interface] = {
    .visible = true,
    .named = true,
  },
  [sym_module] = {
    .visible = true,
    .named = true,
  },
  [sym_implements] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reference_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_schema_field_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__doc_or_meta_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_model_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_defpact_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_let_binding_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_cond_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_def_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_doc_string] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_let_variable_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_governance] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_module_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_parameter_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_property_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_s_expression_head] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_schema_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_table_schema] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_args = 1,
  field_bind_pairs = 2,
  field_body = 3,
  field_branch = 4,
  field_doc = 5,
  field_else_branch = 6,
  field_entity = 7,
  field_event = 8,
  field_expr = 9,
  field_fields = 10,
  field_governance = 11,
  field_hash = 12,
  field_head = 13,
  field_imports = 14,
  field_interface = 15,
  field_key = 16,
  field_managed = 17,
  field_manager = 18,
  field_meta = 19,
  field_model = 20,
  field_module = 21,
  field_name = 22,
  field_namespace = 23,
  field_parameters = 24,
  field_return_type = 25,
  field_rollback_expr = 26,
  field_schema = 27,
  field_tail = 28,
  field_test = 29,
  field_type = 30,
  field_type_parameter = 31,
  field_value = 32,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_args] = "args",
  [field_bind_pairs] = "bind_pairs",
  [field_body] = "body",
  [field_branch] = "branch",
  [field_doc] = "doc",
  [field_else_branch] = "else_branch",
  [field_entity] = "entity",
  [field_event] = "event",
  [field_expr] = "expr",
  [field_fields] = "fields",
  [field_governance] = "governance",
  [field_hash] = "hash",
  [field_head] = "head",
  [field_imports] = "imports",
  [field_interface] = "interface",
  [field_key] = "key",
  [field_managed] = "managed",
  [field_manager] = "manager",
  [field_meta] = "meta",
  [field_model] = "model",
  [field_module] = "module",
  [field_name] = "name",
  [field_namespace] = "namespace",
  [field_parameters] = "parameters",
  [field_return_type] = "return_type",
  [field_rollback_expr] = "rollback_expr",
  [field_schema] = "schema",
  [field_tail] = "tail",
  [field_test] = "test",
  [field_type] = "type",
  [field_type_parameter] = "type_parameter",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 1},
  [6] = {.index = 3, .length = 1},
  [7] = {.index = 4, .length = 1},
  [8] = {.index = 5, .length = 1},
  [9] = {.index = 6, .length = 1},
  [10] = {.index = 7, .length = 1},
  [11] = {.index = 8, .length = 1},
  [12] = {.index = 9, .length = 5},
  [14] = {.index = 14, .length = 2},
  [15] = {.index = 16, .length = 2},
  [17] = {.index = 18, .length = 1},
  [18] = {.index = 19, .length = 1},
  [19] = {.index = 20, .length = 6},
  [20] = {.index = 26, .length = 10},
  [21] = {.index = 36, .length = 2},
  [22] = {.index = 38, .length = 2},
  [23] = {.index = 40, .length = 3},
  [24] = {.index = 43, .length = 2},
  [25] = {.index = 45, .length = 7},
  [26] = {.index = 52, .length = 7},
  [27] = {.index = 59, .length = 3},
  [28] = {.index = 62, .length = 2},
  [29] = {.index = 64, .length = 1},
  [30] = {.index = 65, .length = 4},
  [31] = {.index = 69, .length = 1},
  [32] = {.index = 70, .length = 1},
  [33] = {.index = 71, .length = 8},
  [34] = {.index = 69, .length = 1},
  [35] = {.index = 79, .length = 2},
  [36] = {.index = 81, .length = 3},
  [37] = {.index = 69, .length = 1},
  [38] = {.index = 84, .length = 1},
  [39] = {.index = 85, .length = 2},
  [40] = {.index = 87, .length = 2},
  [41] = {.index = 89, .length = 2},
  [42] = {.index = 91, .length = 1},
  [43] = {.index = 92, .length = 1},
  [44] = {.index = 87, .length = 2},
  [45] = {.index = 93, .length = 3},
  [46] = {.index = 96, .length = 3},
  [47] = {.index = 99, .length = 2},
  [48] = {.index = 87, .length = 2},
  [49] = {.index = 101, .length = 3},
  [50] = {.index = 104, .length = 7},
  [51] = {.index = 111, .length = 3},
  [52] = {.index = 114, .length = 7},
  [53] = {.index = 121, .length = 7},
  [54] = {.index = 128, .length = 1},
  [55] = {.index = 129, .length = 4},
  [56] = {.index = 133, .length = 1},
  [57] = {.index = 134, .length = 8},
  [58] = {.index = 142, .length = 4},
  [59] = {.index = 146, .length = 8},
  [60] = {.index = 154, .length = 1},
  [61] = {.index = 155, .length = 9},
  [62] = {.index = 164, .length = 1},
  [63] = {.index = 165, .length = 2},
  [64] = {.index = 167, .length = 2},
  [65] = {.index = 169, .length = 2},
  [66] = {.index = 171, .length = 3},
  [67] = {.index = 174, .length = 7},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_head, 1},
  [1] =
    {field_namespace, 2},
  [2] =
    {field_module, 2},
  [3] =
    {field_name, 2},
  [4] =
    {field_doc, 0},
  [5] =
    {field_model, 0},
  [6] =
    {field_managed, 0},
  [7] =
    {field_event, 0},
  [8] =
    {field_meta, 0},
  [9] =
    {field_doc, 0, .inherited = true},
    {field_event, 0, .inherited = true},
    {field_managed, 0, .inherited = true},
    {field_meta, 0, .inherited = true},
    {field_model, 0, .inherited = true},
  [14] =
    {field_head, 1},
    {field_tail, 2},
  [16] =
    {field_imports, 3},
    {field_module, 2},
  [18] =
    {field_manager, 1},
  [19] =
    {field_args, 1},
  [20] =
    {field_doc, 3, .inherited = true},
    {field_event, 3, .inherited = true},
    {field_managed, 3, .inherited = true},
    {field_meta, 3, .inherited = true},
    {field_model, 3, .inherited = true},
    {field_name, 2},
  [26] =
    {field_doc, 0, .inherited = true},
    {field_doc, 1, .inherited = true},
    {field_event, 0, .inherited = true},
    {field_event, 1, .inherited = true},
    {field_managed, 0, .inherited = true},
    {field_managed, 1, .inherited = true},
    {field_meta, 0, .inherited = true},
    {field_meta, 1, .inherited = true},
    {field_model, 0, .inherited = true},
    {field_model, 1, .inherited = true},
  [36] =
    {field_body, 3},
    {field_name, 2},
  [38] =
    {field_governance, 3},
    {field_name, 2},
  [40] =
    {field_hash, 3},
    {field_imports, 4},
    {field_module, 2},
  [43] =
    {field_args, 1},
    {field_manager, 2},
  [45] =
    {field_body, 4},
    {field_doc, 3, .inherited = true},
    {field_event, 3, .inherited = true},
    {field_managed, 3, .inherited = true},
    {field_meta, 3, .inherited = true},
    {field_model, 3, .inherited = true},
    {field_name, 2},
  [52] =
    {field_doc, 4, .inherited = true},
    {field_event, 4, .inherited = true},
    {field_governance, 3},
    {field_managed, 4, .inherited = true},
    {field_meta, 4, .inherited = true},
    {field_model, 4, .inherited = true},
    {field_name, 2},
  [59] =
    {field_body, 4},
    {field_governance, 3},
    {field_name, 2},
  [62] =
    {field_key, 0},
    {field_value, 2},
  [64] =
    {field_else_branch, 2},
  [65] =
    {field_branch, 0, .inherited = true},
    {field_branch, 1, .inherited = true},
    {field_test, 0, .inherited = true},
    {field_test, 1, .inherited = true},
  [69] =
    {field_name, 0},
  [70] =
    {field_body, 2},
  [71] =
    {field_body, 5},
    {field_doc, 4, .inherited = true},
    {field_event, 4, .inherited = true},
    {field_governance, 3},
    {field_managed, 4, .inherited = true},
    {field_meta, 4, .inherited = true},
    {field_model, 4, .inherited = true},
    {field_name, 2},
  [79] =
    {field_bind_pairs, 2},
    {field_bind_pairs, 3},
  [81] =
    {field_branch, 2, .inherited = true},
    {field_else_branch, 3},
    {field_test, 2, .inherited = true},
  [84] =
    {field_type_parameter, 0, .inherited = true},
  [85] =
    {field_name, 2},
    {field_parameters, 3},
  [87] =
    {field_name, 0},
    {field_type, 1},
  [89] =
    {field_fields, 3},
    {field_name, 2},
  [91] =
    {field_hash, 2},
  [92] =
    {field_interface, 2},
  [93] =
    {field_bind_pairs, 2},
    {field_bind_pairs, 3},
    {field_body, 4},
  [96] =
    {field_bind_pairs, 2},
    {field_bind_pairs, 3},
    {field_bind_pairs, 4},
  [99] =
    {field_branch, 2},
    {field_test, 1},
  [101] =
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 3},
  [104] =
    {field_doc, 4, .inherited = true},
    {field_event, 4, .inherited = true},
    {field_managed, 4, .inherited = true},
    {field_meta, 4, .inherited = true},
    {field_model, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
  [111] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
  [114] =
    {field_body, 3},
    {field_doc, 4, .inherited = true},
    {field_event, 4, .inherited = true},
    {field_managed, 4, .inherited = true},
    {field_meta, 4, .inherited = true},
    {field_model, 4, .inherited = true},
    {field_name, 2},
  [121] =
    {field_doc, 3, .inherited = true},
    {field_event, 3, .inherited = true},
    {field_fields, 4},
    {field_managed, 3, .inherited = true},
    {field_meta, 3, .inherited = true},
    {field_model, 3, .inherited = true},
    {field_name, 2},
  [128] =
    {field_value, 2},
  [129] =
    {field_bind_pairs, 2},
    {field_bind_pairs, 3},
    {field_bind_pairs, 4},
    {field_body, 5},
  [133] =
    {field_type_parameter, 1},
  [134] =
    {field_doc, 5, .inherited = true},
    {field_event, 5, .inherited = true},
    {field_managed, 5, .inherited = true},
    {field_meta, 5, .inherited = true},
    {field_model, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 3},
  [142] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 3},
  [146] =
    {field_body, 5},
    {field_doc, 4, .inherited = true},
    {field_event, 4, .inherited = true},
    {field_managed, 4, .inherited = true},
    {field_meta, 4, .inherited = true},
    {field_model, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
  [154] =
    {field_type_parameter, 2},
  [155] =
    {field_body, 6},
    {field_doc, 5, .inherited = true},
    {field_event, 5, .inherited = true},
    {field_managed, 5, .inherited = true},
    {field_meta, 5, .inherited = true},
    {field_model, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 3},
  [164] =
    {field_expr, 2},
  [165] =
    {field_entity, 2},
    {field_expr, 3},
  [167] =
    {field_expr, 2},
    {field_rollback_expr, 3},
  [169] =
    {field_name, 2},
    {field_schema, 5},
  [171] =
    {field_entity, 2},
    {field_expr, 3},
    {field_rollback_expr, 4},
  [174] =
    {field_doc, 7, .inherited = true},
    {field_event, 7, .inherited = true},
    {field_managed, 7, .inherited = true},
    {field_meta, 7, .inherited = true},
    {field_model, 7, .inherited = true},
    {field_name, 2},
    {field_schema, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_def_identifier,
  },
  [2] = {
    [1] = alias_sym_s_expression_head,
  },
  [5] = {
    [0] = alias_sym_doc_string,
  },
  [13] = {
    [0] = alias_sym_property_identifier,
  },
  [14] = {
    [1] = alias_sym_s_expression_head,
  },
  [16] = {
    [1] = alias_sym_doc_string,
  },
  [22] = {
    [2] = alias_sym_module_identifier,
    [3] = alias_sym_module_governance,
  },
  [26] = {
    [2] = alias_sym_module_identifier,
    [3] = alias_sym_module_governance,
  },
  [27] = {
    [2] = alias_sym_module_identifier,
    [3] = alias_sym_module_governance,
  },
  [31] = {
    [0] = alias_sym_schema_field_identifier,
  },
  [33] = {
    [2] = alias_sym_module_identifier,
    [3] = alias_sym_module_governance,
  },
  [34] = {
    [0] = alias_sym_let_variable_identifier,
  },
  [37] = {
    [0] = alias_sym_parameter_identifier,
  },
  [40] = {
    [0] = alias_sym_schema_field_identifier,
  },
  [44] = {
    [0] = alias_sym_let_variable_identifier,
  },
  [48] = {
    [0] = alias_sym_parameter_identifier,
  },
  [56] = {
    [1] = alias_sym_type_parameter,
  },
  [60] = {
    [2] = alias_sym_type_parameter,
  },
  [65] = {
    [5] = alias_sym_table_schema,
  },
  [67] = {
    [5] = alias_sym_table_schema,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_reference, 3,
    sym_reference,
    alias_sym_s_expression_head,
    alias_sym_type_parameter,
  sym_type_identifier, 2,
    sym_type_identifier,
    alias_sym_type_parameter,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 14,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 15,
  [39] = 24,
  [40] = 32,
  [41] = 13,
  [42] = 14,
  [43] = 17,
  [44] = 18,
  [45] = 19,
  [46] = 25,
  [47] = 32,
  [48] = 14,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 52,
  [54] = 54,
  [55] = 51,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 15,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 70,
  [72] = 72,
  [73] = 72,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 64,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 66,
  [99] = 8,
  [100] = 74,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 9,
  [106] = 106,
  [107] = 97,
  [108] = 9,
  [109] = 96,
  [110] = 93,
  [111] = 94,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 91,
  [117] = 8,
  [118] = 118,
  [119] = 119,
  [120] = 95,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 124,
  [126] = 124,
  [127] = 124,
  [128] = 128,
  [129] = 129,
  [130] = 64,
  [131] = 66,
  [132] = 132,
  [133] = 133,
  [134] = 92,
  [135] = 76,
  [136] = 136,
  [137] = 74,
  [138] = 138,
  [139] = 136,
  [140] = 96,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 64,
  [150] = 66,
  [151] = 151,
  [152] = 85,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 80,
  [160] = 91,
  [161] = 93,
  [162] = 94,
  [163] = 97,
  [164] = 95,
  [165] = 90,
  [166] = 76,
  [167] = 89,
  [168] = 168,
  [169] = 75,
  [170] = 78,
  [171] = 83,
  [172] = 172,
  [173] = 86,
  [174] = 81,
  [175] = 87,
  [176] = 82,
  [177] = 79,
  [178] = 84,
  [179] = 179,
  [180] = 180,
  [181] = 74,
  [182] = 92,
  [183] = 85,
  [184] = 119,
  [185] = 121,
  [186] = 113,
  [187] = 101,
  [188] = 112,
  [189] = 136,
  [190] = 95,
  [191] = 79,
  [192] = 96,
  [193] = 75,
  [194] = 78,
  [195] = 83,
  [196] = 81,
  [197] = 82,
  [198] = 90,
  [199] = 91,
  [200] = 97,
  [201] = 104,
  [202] = 84,
  [203] = 114,
  [204] = 86,
  [205] = 87,
  [206] = 206,
  [207] = 93,
  [208] = 94,
  [209] = 89,
  [210] = 115,
  [211] = 211,
  [212] = 211,
  [213] = 213,
  [214] = 214,
  [215] = 211,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 222,
  [228] = 226,
  [229] = 229,
  [230] = 141,
  [231] = 222,
  [232] = 226,
  [233] = 216,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 146,
  [239] = 147,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 234,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 246,
  [248] = 248,
  [249] = 249,
  [250] = 142,
  [251] = 148,
  [252] = 252,
  [253] = 253,
  [254] = 246,
  [255] = 143,
  [256] = 144,
  [257] = 236,
  [258] = 258,
  [259] = 258,
  [260] = 145,
  [261] = 261,
  [262] = 261,
  [263] = 263,
  [264] = 264,
  [265] = 264,
  [266] = 266,
  [267] = 261,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 264,
  [273] = 266,
  [274] = 261,
  [275] = 275,
  [276] = 264,
  [277] = 266,
  [278] = 278,
  [279] = 266,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 336,
  [358] = 299,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 377,
  [382] = 382,
  [383] = 360,
  [384] = 362,
  [385] = 362,
  [386] = 386,
  [387] = 387,
  [388] = 379,
  [389] = 378,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 380,
  [395] = 360,
  [396] = 370,
  [397] = 397,
  [398] = 398,
  [399] = 380,
  [400] = 387,
  [401] = 380,
  [402] = 367,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 372,
  [408] = 387,
  [409] = 363,
  [410] = 372,
};

static TSCharacterRange extras_character_set_1[] = {
  {'\t', '\r'}, {' ', ' '}, {0xa0, 0xa0}, {0x1680, 0x1680}, {0x2000, 0x200b}, {0x2028, 0x2029}, {0x202f, 0x202f}, {0x205f, 0x2060},
  {0x3000, 0x3000}, {0xfeff, 0xfeff},
};

static TSCharacterRange sym_symbol_character_set_1[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'!', '!'}, {'#', '&'}, {'*', '+'}, {'-', '-'}, {'/', '9'}, {';', 'Z'},
  {'\\', '\\'}, {'^', 0x10ffff},
};

static TSCharacterRange sym_atom_character_set_2[] = {
  {'!', '!'}, {'#', '&'}, {'*', '+'}, {'-', '-'}, {'/', '9'}, {'<', 'Z'}, {'_', '_'}, {'a', 'z'},
  {'|', '|'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(25);
      ADVANCE_MAP(
        '"', 6,
        '\'', 23,
        '(', 37,
        ')', 38,
        ',', 34,
        '-', 54,
        '.', 56,
        ':', 58,
        ';', 26,
        '@', 68,
        '[', 32,
        ']', 33,
        '{', 35,
        '}', 36,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(27);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(0);
      if (('!' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= '|')) ADVANCE(55);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(5);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '"', 6,
        '\'', 23,
        '(', 37,
        ')', 38,
        ':', 57,
        ';', 26,
        '[', 32,
        ']', 33,
        '{', 35,
      );
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(2);
      if (('!' <= lookahead && lookahead <= '+') ||
          lookahead == '-' ||
          lookahead == '/' ||
          ('<' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= '|')) ADVANCE(55);
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(6);
      if (lookahead == '(') ADVANCE(37);
      if (lookahead == ')') ADVANCE(38);
      if (lookahead == '.') ADVANCE(56);
      if (lookahead == ':') ADVANCE(57);
      if (lookahead == ';') ADVANCE(26);
      if (lookahead == '@') ADVANCE(69);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(3);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(6);
      if (lookahead == '(') ADVANCE(37);
      if (lookahead == ')') ADVANCE(38);
      if (lookahead == '.') ADVANCE(56);
      if (lookahead == ';') ADVANCE(26);
      if (lookahead == '@') ADVANCE(68);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(4);
      if (('!' <= lookahead && lookahead <= '&') ||
          lookahead == '*' ||
          lookahead == '+' ||
          ('-' <= lookahead && lookahead <= '/') ||
          ('<' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z') ||
          lookahead == '|') ADVANCE(55);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(30);
      if (lookahead == '\\') ADVANCE(1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(5);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 6:
      if (lookahead == '"') ADVANCE(30);
      if (lookahead == '\\') ADVANCE(1);
      if (lookahead != 0) ADVANCE(6);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(17);
      if (lookahead == 'o') ADVANCE(11);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(15);
      END_STATE();
    case 9:
      if (lookahead == 'c') ADVANCE(60);
      END_STATE();
    case 10:
      if (lookahead == 'd') ADVANCE(64);
      END_STATE();
    case 11:
      if (lookahead == 'd') ADVANCE(12);
      END_STATE();
    case 12:
      if (lookahead == 'e') ADVANCE(16);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(18);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(10);
      END_STATE();
    case 15:
      if (lookahead == 'g') ADVANCE(14);
      END_STATE();
    case 16:
      if (lookahead == 'l') ADVANCE(62);
      END_STATE();
    case 17:
      if (lookahead == 'n') ADVANCE(8);
      END_STATE();
    case 18:
      if (lookahead == 'n') ADVANCE(20);
      END_STATE();
    case 19:
      if (lookahead == 'o') ADVANCE(9);
      END_STATE();
    case 20:
      if (lookahead == 't') ADVANCE(66);
      END_STATE();
    case 21:
      if (lookahead == 'v') ADVANCE(13);
      END_STATE();
    case 22:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      END_STATE();
    case 23:
      if ((!eof && set_contains(sym_symbol_character_set_1, 10, lookahead))) ADVANCE(31);
      END_STATE();
    case 24:
      if (eof) ADVANCE(25);
      ADVANCE_MAP(
        '"', 6,
        '\'', 23,
        '(', 37,
        ')', 38,
        ',', 34,
        '-', 54,
        '.', 56,
        ':', 57,
        ';', 26,
        '[', 32,
        ']', 33,
        '{', 35,
        '}', 36,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(27);
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(24);
      if (('!' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= '|')) ADVANCE(55);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(26);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(27);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(28);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(sym_decimal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(sym_string);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(sym_symbol);
      if ((!eof && set_contains(sym_symbol_character_set_1, 10, lookahead))) ADVANCE(31);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'a') ADVANCE(49);
      if (lookahead == 'o') ADVANCE(43);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'a') ADVANCE(47);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'c') ADVANCE(61);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'd') ADVANCE(65);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'd') ADVANCE(44);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'e') ADVANCE(48);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'e') ADVANCE(50);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'e') ADVANCE(42);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'g') ADVANCE(46);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'l') ADVANCE(63);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'n') ADVANCE(40);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'n') ADVANCE(52);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'o') ADVANCE(41);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 't') ADVANCE(67);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_atom);
      if (lookahead == 'v') ADVANCE(45);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_atom);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(28);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_atom);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(59);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_ATdoc);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_ATdoc);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_ATmodel);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_ATmodel);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_ATmanaged);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_ATmanaged);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_ATevent);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_ATevent);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == 'd') ADVANCE(51);
      if (lookahead == 'e') ADVANCE(53);
      if (lookahead == 'm') ADVANCE(39);
      if (set_contains(sym_atom_character_set_2, 9, lookahead)) ADVANCE(55);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == 'd') ADVANCE(19);
      if (lookahead == 'e') ADVANCE(21);
      if (lookahead == 'm') ADVANCE(7);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'b', 1,
        'c', 2,
        'd', 3,
        'f', 4,
        'g', 5,
        'i', 6,
        'k', 7,
        'l', 8,
        'm', 9,
        'n', 10,
        'o', 11,
        's', 12,
        't', 13,
        'u', 14,
        'v', 15,
      );
      if (set_contains(extras_character_set_1, 10, lookahead)) SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'l') ADVANCE(16);
      if (lookahead == 'o') ADVANCE(17);
      END_STATE();
    case 2:
      if (lookahead == 'o') ADVANCE(18);
      END_STATE();
    case 3:
      if (lookahead == 'e') ADVANCE(19);
      END_STATE();
    case 4:
      if (lookahead == 'a') ADVANCE(20);
      END_STATE();
    case 5:
      if (lookahead == 'u') ADVANCE(21);
      END_STATE();
    case 6:
      if (lookahead == 'm') ADVANCE(22);
      if (lookahead == 'n') ADVANCE(23);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(24);
      END_STATE();
    case 8:
      if (lookahead == 'e') ADVANCE(25);
      if (lookahead == 'i') ADVANCE(26);
      END_STATE();
    case 9:
      if (lookahead == 'o') ADVANCE(27);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(28);
      END_STATE();
    case 11:
      if (lookahead == 'b') ADVANCE(29);
      END_STATE();
    case 12:
      if (lookahead == 't') ADVANCE(30);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(31);
      if (lookahead == 'i') ADVANCE(32);
      if (lookahead == 'r') ADVANCE(33);
      END_STATE();
    case 14:
      if (lookahead == 's') ADVANCE(34);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(35);
      END_STATE();
    case 16:
      if (lookahead == 'e') ADVANCE(36);
      END_STATE();
    case 17:
      if (lookahead == 'o') ADVANCE(37);
      END_STATE();
    case 18:
      if (lookahead == 'n') ADVANCE(38);
      END_STATE();
    case 19:
      if (lookahead == 'c') ADVANCE(39);
      if (lookahead == 'f') ADVANCE(40);
      END_STATE();
    case 20:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(42);
      END_STATE();
    case 22:
      if (lookahead == 'p') ADVANCE(43);
      END_STATE();
    case 23:
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 24:
      if (lookahead == 'y') ADVANCE(45);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(46);
      END_STATE();
    case 26:
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 27:
      if (lookahead == 'd') ADVANCE(48);
      END_STATE();
    case 28:
      if (lookahead == 'm') ADVANCE(49);
      END_STATE();
    case 29:
      if (lookahead == 'j') ADVANCE(50);
      END_STATE();
    case 30:
      if (lookahead == 'e') ADVANCE(51);
      if (lookahead == 'r') ADVANCE(52);
      END_STATE();
    case 31:
      if (lookahead == 'b') ADVANCE(53);
      END_STATE();
    case 32:
      if (lookahead == 'm') ADVANCE(54);
      END_STATE();
    case 33:
      if (lookahead == 'u') ADVANCE(55);
      END_STATE();
    case 34:
      if (lookahead == 'e') ADVANCE(56);
      END_STATE();
    case 35:
      if (lookahead == 'l') ADVANCE(57);
      END_STATE();
    case 36:
      if (lookahead == 's') ADVANCE(58);
      END_STATE();
    case 37:
      if (lookahead == 'l') ADVANCE(59);
      END_STATE();
    case 38:
      if (lookahead == 'd') ADVANCE(60);
      END_STATE();
    case 39:
      if (lookahead == 'i') ADVANCE(61);
      END_STATE();
    case 40:
      if (lookahead == 'c') ADVANCE(62);
      if (lookahead == 'p') ADVANCE(63);
      if (lookahead == 's') ADVANCE(64);
      if (lookahead == 't') ADVANCE(65);
      if (lookahead == 'u') ADVANCE(66);
      END_STATE();
    case 41:
      if (lookahead == 's') ADVANCE(67);
      END_STATE();
    case 42:
      if (lookahead == 'r') ADVANCE(68);
      END_STATE();
    case 43:
      if (lookahead == 'l') ADVANCE(69);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 45:
      if (lookahead == 's') ADVANCE(71);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_let);
      if (lookahead == '*') ADVANCE(72);
      END_STATE();
    case 47:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 48:
      if (lookahead == 'u') ADVANCE(74);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 51:
      if (lookahead == 'p') ADVANCE(77);
      END_STATE();
    case 52:
      if (lookahead == 'i') ADVANCE(78);
      END_STATE();
    case 53:
      if (lookahead == 'l') ADVANCE(79);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(80);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_use);
      END_STATE();
    case 57:
      if (lookahead == 'u') ADVANCE(82);
      END_STATE();
    case 58:
      if (lookahead == 's') ADVANCE(83);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_cond);
      END_STATE();
    case 61:
      if (lookahead == 'm') ADVANCE(84);
      END_STATE();
    case 62:
      if (lookahead == 'a') ADVANCE(85);
      if (lookahead == 'o') ADVANCE(86);
      END_STATE();
    case 63:
      if (lookahead == 'a') ADVANCE(87);
      if (lookahead == 'r') ADVANCE(88);
      END_STATE();
    case 64:
      if (lookahead == 'c') ADVANCE(89);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(90);
      END_STATE();
    case 66:
      if (lookahead == 'n') ADVANCE(91);
      END_STATE();
    case 67:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 68:
      if (lookahead == 'd') ADVANCE(92);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 70:
      if (lookahead == 'g') ADVANCE(94);
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(96);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_let_STAR);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_list);
      END_STATE();
    case 74:
      if (lookahead == 'l') ADVANCE(97);
      END_STATE();
    case 75:
      if (lookahead == 's') ADVANCE(98);
      END_STATE();
    case 76:
      if (lookahead == 'c') ADVANCE(99);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_step);
      if (lookahead == '-') ADVANCE(100);
      END_STATE();
    case 78:
      if (lookahead == 'n') ADVANCE(101);
      END_STATE();
    case 79:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_time);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(sym_boolean);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_bless);
      END_STATE();
    case 84:
      if (lookahead == 'a') ADVANCE(104);
      END_STATE();
    case 85:
      if (lookahead == 'p') ADVANCE(105);
      END_STATE();
    case 86:
      if (lookahead == 'n') ADVANCE(106);
      END_STATE();
    case 87:
      if (lookahead == 'c') ADVANCE(107);
      END_STATE();
    case 88:
      if (lookahead == 'o') ADVANCE(108);
      END_STATE();
    case 89:
      if (lookahead == 'h') ADVANCE(109);
      END_STATE();
    case 90:
      if (lookahead == 'b') ADVANCE(110);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_defun);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_guard);
      END_STATE();
    case 93:
      if (lookahead == 'm') ADVANCE(111);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(112);
      END_STATE();
    case 95:
      if (lookahead == 'f') ADVANCE(113);
      END_STATE();
    case 96:
      if (lookahead == 't') ADVANCE(114);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 98:
      if (lookahead == 'p') ADVANCE(116);
      END_STATE();
    case 99:
      if (lookahead == 't') ADVANCE(117);
      END_STATE();
    case 100:
      if (lookahead == 'w') ADVANCE(118);
      END_STATE();
    case 101:
      if (lookahead == 'g') ADVANCE(119);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_table);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_value);
      END_STATE();
    case 104:
      if (lookahead == 'l') ADVANCE(120);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_defcap);
      END_STATE();
    case 106:
      if (lookahead == 's') ADVANCE(121);
      END_STATE();
    case 107:
      if (lookahead == 't') ADVANCE(122);
      END_STATE();
    case 108:
      if (lookahead == 'p') ADVANCE(123);
      END_STATE();
    case 109:
      if (lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 110:
      if (lookahead == 'l') ADVANCE(125);
      END_STATE();
    case 111:
      if (lookahead == 'e') ADVANCE(126);
      END_STATE();
    case 112:
      if (lookahead == 'r') ADVANCE(127);
      END_STATE();
    case 113:
      if (lookahead == 'a') ADVANCE(128);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_keyset);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 116:
      if (lookahead == 'a') ADVANCE(129);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_object);
      END_STATE();
    case 118:
      if (lookahead == 'i') ADVANCE(130);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_decimal);
      END_STATE();
    case 121:
      if (lookahead == 't') ADVANCE(131);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_defpact);
      END_STATE();
    case 123:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 124:
      if (lookahead == 'm') ADVANCE(133);
      END_STATE();
    case 125:
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 126:
      if (lookahead == 'n') ADVANCE(135);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_integer);
      END_STATE();
    case 128:
      if (lookahead == 'c') ADVANCE(136);
      END_STATE();
    case 129:
      if (lookahead == 'c') ADVANCE(137);
      END_STATE();
    case 130:
      if (lookahead == 't') ADVANCE(138);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_defconst);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(139);
      END_STATE();
    case 133:
      if (lookahead == 'a') ADVANCE(140);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_deftable);
      END_STATE();
    case 135:
      if (lookahead == 't') ADVANCE(141);
      END_STATE();
    case 136:
      if (lookahead == 'e') ADVANCE(142);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(143);
      END_STATE();
    case 138:
      if (lookahead == 'h') ADVANCE(144);
      END_STATE();
    case 139:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_defschema);
      END_STATE();
    case 141:
      if (lookahead == 's') ADVANCE(146);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 144:
      if (lookahead == '-') ADVANCE(147);
      END_STATE();
    case 145:
      if (lookahead == 'y') ADVANCE(148);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 147:
      if (lookahead == 'r') ADVANCE(149);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_defproperty);
      END_STATE();
    case 149:
      if (lookahead == 'o') ADVANCE(150);
      END_STATE();
    case 150:
      if (lookahead == 'l') ADVANCE(151);
      END_STATE();
    case 151:
      if (lookahead == 'l') ADVANCE(152);
      END_STATE();
    case 152:
      if (lookahead == 'b') ADVANCE(153);
      END_STATE();
    case 153:
      if (lookahead == 'a') ADVANCE(154);
      END_STATE();
    case 154:
      if (lookahead == 'c') ADVANCE(155);
      END_STATE();
    case 155:
      if (lookahead == 'k') ADVANCE(156);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_step_DASHwith_DASHrollback);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 0},
  [4] = {.lex_state = 0},
  [5] = {.lex_state = 0},
  [6] = {.lex_state = 3},
  [7] = {.lex_state = 3},
  [8] = {.lex_state = 0},
  [9] = {.lex_state = 0},
  [10] = {.lex_state = 24},
  [11] = {.lex_state = 24},
  [12] = {.lex_state = 24},
  [13] = {.lex_state = 24},
  [14] = {.lex_state = 24},
  [15] = {.lex_state = 0},
  [16] = {.lex_state = 24},
  [17] = {.lex_state = 24},
  [18] = {.lex_state = 24},
  [19] = {.lex_state = 24},
  [20] = {.lex_state = 24},
  [21] = {.lex_state = 24},
  [22] = {.lex_state = 24},
  [23] = {.lex_state = 24},
  [24] = {.lex_state = 24},
  [25] = {.lex_state = 24},
  [26] = {.lex_state = 24},
  [27] = {.lex_state = 24},
  [28] = {.lex_state = 24},
  [29] = {.lex_state = 24},
  [30] = {.lex_state = 24},
  [31] = {.lex_state = 24},
  [32] = {.lex_state = 24},
  [33] = {.lex_state = 24},
  [34] = {.lex_state = 24},
  [35] = {.lex_state = 24},
  [36] = {.lex_state = 24},
  [37] = {.lex_state = 24},
  [38] = {.lex_state = 0},
  [39] = {.lex_state = 24},
  [40] = {.lex_state = 24},
  [41] = {.lex_state = 24},
  [42] = {.lex_state = 24},
  [43] = {.lex_state = 24},
  [44] = {.lex_state = 24},
  [45] = {.lex_state = 24},
  [46] = {.lex_state = 24},
  [47] = {.lex_state = 24},
  [48] = {.lex_state = 24},
  [49] = {.lex_state = 24},
  [50] = {.lex_state = 3},
  [51] = {.lex_state = 24},
  [52] = {.lex_state = 24},
  [53] = {.lex_state = 24},
  [54] = {.lex_state = 3},
  [55] = {.lex_state = 24},
  [56] = {.lex_state = 24},
  [57] = {.lex_state = 24},
  [58] = {.lex_state = 24},
  [59] = {.lex_state = 24},
  [60] = {.lex_state = 24},
  [61] = {.lex_state = 24},
  [62] = {.lex_state = 24},
  [63] = {.lex_state = 4},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 24},
  [68] = {.lex_state = 24},
  [69] = {.lex_state = 24},
  [70] = {.lex_state = 2},
  [71] = {.lex_state = 2},
  [72] = {.lex_state = 2},
  [73] = {.lex_state = 2},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 0},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 24},
  [81] = {.lex_state = 0},
  [82] = {.lex_state = 0},
  [83] = {.lex_state = 0},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 24},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 0},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 24},
  [99] = {.lex_state = 3},
  [100] = {.lex_state = 24},
  [101] = {.lex_state = 24},
  [102] = {.lex_state = 24},
  [103] = {.lex_state = 3},
  [104] = {.lex_state = 24},
  [105] = {.lex_state = 3},
  [106] = {.lex_state = 3},
  [107] = {.lex_state = 24},
  [108] = {.lex_state = 4},
  [109] = {.lex_state = 24},
  [110] = {.lex_state = 24},
  [111] = {.lex_state = 24},
  [112] = {.lex_state = 24},
  [113] = {.lex_state = 24},
  [114] = {.lex_state = 24},
  [115] = {.lex_state = 24},
  [116] = {.lex_state = 24},
  [117] = {.lex_state = 4},
  [118] = {.lex_state = 24},
  [119] = {.lex_state = 24},
  [120] = {.lex_state = 24},
  [121] = {.lex_state = 24},
  [122] = {.lex_state = 0},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 24},
  [125] = {.lex_state = 24},
  [126] = {.lex_state = 24},
  [127] = {.lex_state = 24},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 0},
  [130] = {.lex_state = 4},
  [131] = {.lex_state = 4},
  [132] = {.lex_state = 4},
  [133] = {.lex_state = 24},
  [134] = {.lex_state = 24},
  [135] = {.lex_state = 24},
  [136] = {.lex_state = 24},
  [137] = {.lex_state = 4},
  [138] = {.lex_state = 24},
  [139] = {.lex_state = 3},
  [140] = {.lex_state = 4},
  [141] = {.lex_state = 24},
  [142] = {.lex_state = 24},
  [143] = {.lex_state = 24},
  [144] = {.lex_state = 24},
  [145] = {.lex_state = 24},
  [146] = {.lex_state = 24},
  [147] = {.lex_state = 24},
  [148] = {.lex_state = 24},
  [149] = {.lex_state = 3},
  [150] = {.lex_state = 3},
  [151] = {.lex_state = 0},
  [152] = {.lex_state = 4},
  [153] = {.lex_state = 0},
  [154] = {.lex_state = 0},
  [155] = {.lex_state = 2},
  [156] = {.lex_state = 0},
  [157] = {.lex_state = 24},
  [158] = {.lex_state = 24},
  [159] = {.lex_state = 3},
  [160] = {.lex_state = 4},
  [161] = {.lex_state = 4},
  [162] = {.lex_state = 4},
  [163] = {.lex_state = 4},
  [164] = {.lex_state = 4},
  [165] = {.lex_state = 3},
  [166] = {.lex_state = 3},
  [167] = {.lex_state = 3},
  [168] = {.lex_state = 2},
  [169] = {.lex_state = 3},
  [170] = {.lex_state = 3},
  [171] = {.lex_state = 3},
  [172] = {.lex_state = 3},
  [173] = {.lex_state = 3},
  [174] = {.lex_state = 3},
  [175] = {.lex_state = 3},
  [176] = {.lex_state = 3},
  [177] = {.lex_state = 3},
  [178] = {.lex_state = 3},
  [179] = {.lex_state = 0},
  [180] = {.lex_state = 0},
  [181] = {.lex_state = 3},
  [182] = {.lex_state = 3},
  [183] = {.lex_state = 4},
  [184] = {.lex_state = 3},
  [185] = {.lex_state = 3},
  [186] = {.lex_state = 3},
  [187] = {.lex_state = 3},
  [188] = {.lex_state = 3},
  [189] = {.lex_state = 4},
  [190] = {.lex_state = 3},
  [191] = {.lex_state = 4},
  [192] = {.lex_state = 3},
  [193] = {.lex_state = 4},
  [194] = {.lex_state = 4},
  [195] = {.lex_state = 4},
  [196] = {.lex_state = 4},
  [197] = {.lex_state = 4},
  [198] = {.lex_state = 4},
  [199] = {.lex_state = 3},
  [200] = {.lex_state = 3},
  [201] = {.lex_state = 3},
  [202] = {.lex_state = 4},
  [203] = {.lex_state = 3},
  [204] = {.lex_state = 4},
  [205] = {.lex_state = 4},
  [206] = {.lex_state = 2},
  [207] = {.lex_state = 3},
  [208] = {.lex_state = 3},
  [209] = {.lex_state = 4},
  [210] = {.lex_state = 3},
  [211] = {.lex_state = 0},
  [212] = {.lex_state = 0},
  [213] = {.lex_state = 2},
  [214] = {.lex_state = 2},
  [215] = {.lex_state = 0},
  [216] = {.lex_state = 2},
  [217] = {.lex_state = 0},
  [218] = {.lex_state = 0},
  [219] = {.lex_state = 0},
  [220] = {.lex_state = 0},
  [221] = {.lex_state = 0},
  [222] = {.lex_state = 0},
  [223] = {.lex_state = 0},
  [224] = {.lex_state = 0},
  [225] = {.lex_state = 0},
  [226] = {.lex_state = 0},
  [227] = {.lex_state = 0},
  [228] = {.lex_state = 0},
  [229] = {.lex_state = 0},
  [230] = {.lex_state = 2},
  [231] = {.lex_state = 0},
  [232] = {.lex_state = 0},
  [233] = {.lex_state = 2},
  [234] = {.lex_state = 2},
  [235] = {.lex_state = 0},
  [236] = {.lex_state = 0},
  [237] = {.lex_state = 2},
  [238] = {.lex_state = 2},
  [239] = {.lex_state = 2},
  [240] = {.lex_state = 3},
  [241] = {.lex_state = 2},
  [242] = {.lex_state = 2},
  [243] = {.lex_state = 2},
  [244] = {.lex_state = 3},
  [245] = {.lex_state = 2},
  [246] = {.lex_state = 2},
  [247] = {.lex_state = 2},
  [248] = {.lex_state = 2},
  [249] = {.lex_state = 0},
  [250] = {.lex_state = 2},
  [251] = {.lex_state = 2},
  [252] = {.lex_state = 3},
  [253] = {.lex_state = 2},
  [254] = {.lex_state = 2},
  [255] = {.lex_state = 2},
  [256] = {.lex_state = 2},
  [257] = {.lex_state = 0},
  [258] = {.lex_state = 0},
  [259] = {.lex_state = 0},
  [260] = {.lex_state = 2},
  [261] = {.lex_state = 0},
  [262] = {.lex_state = 0},
  [263] = {.lex_state = 0},
  [264] = {.lex_state = 0},
  [265] = {.lex_state = 0},
  [266] = {.lex_state = 0},
  [267] = {.lex_state = 0},
  [268] = {.lex_state = 0},
  [269] = {.lex_state = 2},
  [270] = {.lex_state = 0},
  [271] = {.lex_state = 2},
  [272] = {.lex_state = 0},
  [273] = {.lex_state = 0},
  [274] = {.lex_state = 0},
  [275] = {.lex_state = 0},
  [276] = {.lex_state = 0},
  [277] = {.lex_state = 0},
  [278] = {.lex_state = 0},
  [279] = {.lex_state = 0},
  [280] = {.lex_state = 0},
  [281] = {.lex_state = 0},
  [282] = {.lex_state = 0},
  [283] = {.lex_state = 2},
  [284] = {.lex_state = 2},
  [285] = {.lex_state = 0},
  [286] = {.lex_state = 0},
  [287] = {.lex_state = 0},
  [288] = {.lex_state = 2},
  [289] = {.lex_state = 0},
  [290] = {.lex_state = 0},
  [291] = {.lex_state = 0},
  [292] = {.lex_state = 0},
  [293] = {.lex_state = 0},
  [294] = {.lex_state = 0},
  [295] = {.lex_state = 0},
  [296] = {.lex_state = 2},
  [297] = {.lex_state = 2},
  [298] = {.lex_state = 0},
  [299] = {.lex_state = 2},
  [300] = {.lex_state = 0},
  [301] = {.lex_state = 0},
  [302] = {.lex_state = 0},
  [303] = {.lex_state = 0},
  [304] = {.lex_state = 0},
  [305] = {.lex_state = 0},
  [306] = {.lex_state = 0},
  [307] = {.lex_state = 0},
  [308] = {.lex_state = 0},
  [309] = {.lex_state = 0},
  [310] = {.lex_state = 0},
  [311] = {.lex_state = 2},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 0},
  [314] = {.lex_state = 0},
  [315] = {.lex_state = 0},
  [316] = {.lex_state = 0},
  [317] = {.lex_state = 0},
  [318] = {.lex_state = 0},
  [319] = {.lex_state = 0},
  [320] = {.lex_state = 0},
  [321] = {.lex_state = 0},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 0},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 0},
  [331] = {.lex_state = 0},
  [332] = {.lex_state = 0},
  [333] = {.lex_state = 2},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 2},
  [337] = {.lex_state = 0},
  [338] = {.lex_state = 0},
  [339] = {.lex_state = 0},
  [340] = {.lex_state = 0},
  [341] = {.lex_state = 2},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 2},
  [344] = {.lex_state = 0},
  [345] = {.lex_state = 0},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 0},
  [348] = {.lex_state = 0},
  [349] = {.lex_state = 0},
  [350] = {.lex_state = 2},
  [351] = {.lex_state = 2},
  [352] = {.lex_state = 2},
  [353] = {.lex_state = 0},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 2},
  [357] = {.lex_state = 2},
  [358] = {.lex_state = 2},
  [359] = {.lex_state = 2},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 0},
  [362] = {.lex_state = 2},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 0},
  [365] = {.lex_state = 0},
  [366] = {.lex_state = 0},
  [367] = {.lex_state = 0},
  [368] = {.lex_state = 0},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 0},
  [371] = {.lex_state = 0},
  [372] = {.lex_state = 2},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 2},
  [375] = {.lex_state = 0},
  [376] = {.lex_state = 0},
  [377] = {.lex_state = 0},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 2},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 2},
  [385] = {.lex_state = 2},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 0},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 0},
  [390] = {.lex_state = 0},
  [391] = {.lex_state = 2},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 0},
  [394] = {.lex_state = 2},
  [395] = {.lex_state = 0},
  [396] = {.lex_state = 0},
  [397] = {.lex_state = 0},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 2},
  [400] = {.lex_state = 0},
  [401] = {.lex_state = 2},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 0},
  [405] = {.lex_state = 3},
  [406] = {.lex_state = 2},
  [407] = {.lex_state = 2},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 2},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_atom] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_integer] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [sym_string] = ACTIONS(1),
    [sym_boolean] = ACTIONS(1),
    [sym_symbol] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_object] = ACTIONS(1),
    [anon_sym_table] = ACTIONS(1),
    [anon_sym_integer] = ACTIONS(1),
    [anon_sym_decimal] = ACTIONS(1),
    [anon_sym_time] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_list] = ACTIONS(1),
    [anon_sym_value] = ACTIONS(1),
    [anon_sym_keyset] = ACTIONS(1),
    [anon_sym_guard] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_ATdoc] = ACTIONS(1),
    [anon_sym_ATmodel] = ACTIONS(1),
    [anon_sym_defproperty] = ACTIONS(1),
    [anon_sym_ATmanaged] = ACTIONS(1),
    [anon_sym_ATevent] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_bless] = ACTIONS(1),
    [anon_sym_defun] = ACTIONS(1),
    [anon_sym_defcap] = ACTIONS(1),
    [anon_sym_defconst] = ACTIONS(1),
    [anon_sym_defpact] = ACTIONS(1),
    [anon_sym_defschema] = ACTIONS(1),
    [anon_sym_deftable] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_let_STAR] = ACTIONS(1),
    [anon_sym_cond] = ACTIONS(1),
    [anon_sym_step] = ACTIONS(1),
    [anon_sym_step_DASHwith_DASHrollback] = ACTIONS(1),
    [anon_sym_use] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(398),
    [sym_s_expression] = STATE(179),
    [sym_namespace] = STATE(179),
    [sym_use] = STATE(179),
    [sym_interface] = STATE(179),
    [sym_module] = STATE(179),
    [aux_sym_source_file_repeat1] = STATE(179),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(7),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(15), 1,
      sym_string,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_RPAREN,
    ACTIONS(25), 1,
      anon_sym_ATdoc,
    ACTIONS(27), 1,
      anon_sym_ATmodel,
    ACTIONS(29), 1,
      anon_sym_ATmanaged,
    ACTIONS(31), 1,
      anon_sym_ATevent,
    ACTIONS(33), 1,
      anon_sym_AT,
    STATE(8), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(22), 1,
      sym__doc_or_meta,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(11), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(13), 2,
      sym_decimal,
      sym_symbol,
    STATE(23), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [77] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(15), 1,
      sym_string,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      anon_sym_ATdoc,
    ACTIONS(27), 1,
      anon_sym_ATmodel,
    ACTIONS(29), 1,
      anon_sym_ATmanaged,
    ACTIONS(31), 1,
      anon_sym_ATevent,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(39), 1,
      anon_sym_RPAREN,
    STATE(8), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(26), 1,
      sym__doc_or_meta,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(35), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(37), 2,
      sym_decimal,
      sym_symbol,
    STATE(27), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [154] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(15), 1,
      sym_string,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      anon_sym_ATdoc,
    ACTIONS(27), 1,
      anon_sym_ATmodel,
    ACTIONS(29), 1,
      anon_sym_ATmanaged,
    ACTIONS(31), 1,
      anon_sym_ATevent,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(45), 1,
      anon_sym_RPAREN,
    STATE(8), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(29), 1,
      sym__doc_or_meta,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(41), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(43), 2,
      sym_decimal,
      sym_symbol,
    STATE(30), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [231] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(15), 1,
      sym_string,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      anon_sym_ATdoc,
    ACTIONS(27), 1,
      anon_sym_ATmodel,
    ACTIONS(29), 1,
      anon_sym_ATmanaged,
    ACTIONS(31), 1,
      anon_sym_ATevent,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(51), 1,
      anon_sym_RPAREN,
    STATE(8), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(20), 1,
      sym__doc_or_meta,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(47), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(49), 2,
      sym_decimal,
      sym_symbol,
    STATE(21), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [308] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(55), 1,
      anon_sym_LPAREN,
    ACTIONS(57), 1,
      anon_sym_RPAREN,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(128), 1,
      sym__doc_or_meta,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(129), 10,
      sym_bless,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_deftable,
      sym_use,
      sym_implements,
      aux_sym_module_repeat1,
  [369] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    ACTIONS(69), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_RPAREN,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(156), 1,
      sym__doc_or_meta,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(151), 7,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_use,
      aux_sym_interface_repeat1,
  [427] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(25), 1,
      anon_sym_ATdoc,
    ACTIONS(27), 1,
      anon_sym_ATmodel,
    ACTIONS(29), 1,
      anon_sym_ATmanaged,
    ACTIONS(31), 1,
      anon_sym_ATevent,
    ACTIONS(33), 1,
      anon_sym_AT,
    STATE(9), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(73), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(75), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [478] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(81), 1,
      sym_string,
    ACTIONS(84), 1,
      anon_sym_ATdoc,
    ACTIONS(87), 1,
      anon_sym_ATmodel,
    ACTIONS(90), 1,
      anon_sym_ATmanaged,
    ACTIONS(93), 1,
      anon_sym_ATevent,
    ACTIONS(96), 1,
      anon_sym_AT,
    STATE(9), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(75), 1,
      sym_doc,
    STATE(78), 1,
      sym_model,
    STATE(81), 1,
      sym_event,
    STATE(82), 1,
      sym_meta,
    STATE(83), 1,
      sym_managed,
    ACTIONS(77), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(79), 6,
      sym_decimal,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [531] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(103), 1,
      anon_sym_LPAREN,
    ACTIONS(105), 1,
      anon_sym_RPAREN,
    STATE(49), 1,
      sym_parameter_list,
    ACTIONS(99), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(101), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(33), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [573] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_RPAREN,
    ACTIONS(113), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_reference_repeat1,
    ACTIONS(107), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(109), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(376), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [617] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(115), 1,
      sym_atom,
    ACTIONS(124), 1,
      anon_sym_LBRACK,
    ACTIONS(129), 1,
      anon_sym_LBRACE,
    ACTIONS(132), 1,
      anon_sym_LPAREN,
    ACTIONS(118), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(127), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(121), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [657] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(139), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [696] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(141), 1,
      anon_sym_RBRACK,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [735] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(143), 1,
      sym_atom,
    ACTIONS(151), 1,
      anon_sym_LBRACK,
    ACTIONS(153), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(147), 2,
      sym_decimal,
      sym_symbol,
    ACTIONS(149), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    STATE(152), 4,
      sym_list,
      sym_object,
      sym__literal,
      sym_reference,
    ACTIONS(155), 5,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [774] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(157), 1,
      anon_sym_RBRACK,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [813] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(163), 1,
      anon_sym_RPAREN,
    ACTIONS(159), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(161), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(18), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [852] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(165), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [891] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_RPAREN,
    ACTIONS(167), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(169), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(25), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [930] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(177), 1,
      anon_sym_RPAREN,
    ACTIONS(173), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(175), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(28), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [969] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(179), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1008] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(185), 1,
      anon_sym_RPAREN,
    ACTIONS(181), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(183), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(31), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1047] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(187), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1086] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(193), 1,
      anon_sym_RPAREN,
    ACTIONS(189), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(191), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(13), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1125] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(195), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1164] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(201), 1,
      anon_sym_RPAREN,
    ACTIONS(197), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(199), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(34), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1203] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(203), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1242] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(205), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1281] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(211), 1,
      anon_sym_RPAREN,
    ACTIONS(207), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(209), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(35), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1320] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(213), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1359] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(215), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1398] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(221), 1,
      anon_sym_RBRACK,
    STATE(16), 1,
      aux_sym_list_repeat1,
    ACTIONS(217), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(219), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(127), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [1439] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(223), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1478] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(225), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1517] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(227), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1556] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_reference_repeat1,
    ACTIONS(229), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(111), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    STATE(69), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [1589] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(231), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(85), 4,
      sym_list,
      sym_object,
      sym__literal,
      sym_reference,
    ACTIONS(149), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(155), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [1657] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_RPAREN,
    ACTIONS(233), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(235), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(41), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1696] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(243), 1,
      anon_sym_RBRACK,
    STATE(42), 1,
      aux_sym_list_repeat1,
    ACTIONS(239), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(241), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(126), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [1737] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(245), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1776] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(247), 1,
      anon_sym_RBRACK,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1815] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(253), 1,
      anon_sym_RPAREN,
    ACTIONS(249), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(251), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(44), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1854] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(255), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1893] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(261), 1,
      anon_sym_RPAREN,
    ACTIONS(257), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(259), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(46), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1932] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(263), 1,
      anon_sym_RPAREN,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [1971] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(269), 1,
      anon_sym_RBRACK,
    STATE(48), 1,
      aux_sym_list_repeat1,
    ACTIONS(265), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(267), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(124), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2012] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(271), 1,
      anon_sym_RBRACK,
    ACTIONS(135), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(137), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(12), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [2051] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(277), 1,
      anon_sym_RPAREN,
    ACTIONS(273), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(275), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(37), 9,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
      aux_sym_list_repeat1,
  [2090] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(281), 1,
      anon_sym_RPAREN,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(220), 1,
      sym__doc_or_meta,
    STATE(221), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [2144] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    STATE(52), 1,
      aux_sym_cond_repeat1,
    ACTIONS(283), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(285), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(402), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2182] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    STATE(138), 1,
      aux_sym_cond_repeat1,
    ACTIONS(289), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(291), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(396), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2220] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    STATE(138), 1,
      aux_sym_cond_repeat1,
    ACTIONS(293), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(295), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(370), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2258] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(297), 1,
      anon_sym_RPAREN,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(225), 1,
      sym__doc_or_meta,
    STATE(218), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [2312] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(287), 1,
      anon_sym_LPAREN,
    STATE(53), 1,
      aux_sym_cond_repeat1,
    ACTIONS(299), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(301), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(367), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2350] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(303), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(305), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(392), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2385] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(307), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(309), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(353), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2420] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(311), 1,
      sym_atom,
    ACTIONS(313), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(315), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(361), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2455] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(317), 1,
      sym_atom,
    ACTIONS(319), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(321), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(62), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2490] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(323), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(325), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(334), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2525] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(327), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(329), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(355), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2560] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(331), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(333), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(386), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2595] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(335), 1,
      sym_atom,
    ACTIONS(337), 1,
      sym_string,
    ACTIONS(339), 1,
      anon_sym_ATdoc,
    ACTIONS(341), 1,
      anon_sym_ATmodel,
    ACTIONS(343), 1,
      anon_sym_ATmanaged,
    ACTIONS(345), 1,
      anon_sym_ATevent,
    ACTIONS(347), 1,
      anon_sym_AT,
    STATE(117), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(193), 1,
      sym_doc,
    STATE(194), 1,
      sym_model,
    STATE(195), 1,
      sym_managed,
    STATE(196), 1,
      sym_event,
    STATE(197), 1,
      sym_meta,
    STATE(242), 1,
      sym__doc_or_meta,
    STATE(369), 1,
      sym_schema_field_list,
    STATE(248), 2,
      sym_schema_field,
      aux_sym_schema_field_list_repeat1,
  [2648] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(353), 1,
      anon_sym_DOT,
    STATE(66), 1,
      aux_sym_reference_repeat1,
    ACTIONS(351), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(349), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [2677] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(149), 1,
      sym_string,
    ACTIONS(151), 1,
      anon_sym_LBRACK,
    ACTIONS(153), 1,
      anon_sym_LBRACE,
    ACTIONS(355), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(357), 2,
      sym_decimal,
      sym_symbol,
    STATE(183), 4,
      sym_list,
      sym_object,
      sym__literal,
      sym_reference,
    ACTIONS(155), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [2712] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_DOT,
    STATE(66), 1,
      aux_sym_reference_repeat1,
    ACTIONS(361), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(359), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [2741] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(366), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(368), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(397), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2776] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(370), 1,
      sym_atom,
    ACTIONS(376), 1,
      anon_sym_LBRACK,
    ACTIONS(378), 1,
      anon_sym_LBRACE,
    ACTIONS(380), 1,
      anon_sym_LPAREN,
    ACTIONS(372), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(374), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(106), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2811] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_atom,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(382), 2,
      sym_integer,
      sym_boolean,
    ACTIONS(384), 3,
      sym_decimal,
      sym_string,
      sym_symbol,
    STATE(390), 8,
      sym_list,
      sym_object,
      sym__literal,
      sym__from,
      sym_s_expression,
      sym_reference,
      sym_let_binding,
      sym_cond,
  [2846] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      anon_sym_LBRACK,
    ACTIONS(388), 1,
      anon_sym_LBRACE,
    STATE(255), 1,
      sym__parametrized_object,
    STATE(256), 1,
      sym__parametrized_list,
    STATE(381), 1,
      sym_type_identifier,
    ACTIONS(390), 2,
      anon_sym_object,
      anon_sym_table,
    ACTIONS(392), 9,
      anon_sym_integer,
      anon_sym_decimal,
      anon_sym_time,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_list,
      anon_sym_value,
      anon_sym_keyset,
      anon_sym_guard,
  [2880] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      anon_sym_LBRACK,
    ACTIONS(388), 1,
      anon_sym_LBRACE,
    STATE(255), 1,
      sym__parametrized_object,
    STATE(256), 1,
      sym__parametrized_list,
    STATE(377), 1,
      sym_type_identifier,
    ACTIONS(390), 2,
      anon_sym_object,
      anon_sym_table,
    ACTIONS(392), 9,
      anon_sym_integer,
      anon_sym_decimal,
      anon_sym_time,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_list,
      anon_sym_value,
      anon_sym_keyset,
      anon_sym_guard,
  [2914] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      anon_sym_LBRACK,
    ACTIONS(388), 1,
      anon_sym_LBRACE,
    STATE(255), 1,
      sym__parametrized_object,
    STATE(256), 1,
      sym__parametrized_list,
    STATE(260), 1,
      sym_type_identifier,
    ACTIONS(390), 2,
      anon_sym_object,
      anon_sym_table,
    ACTIONS(392), 9,
      anon_sym_integer,
      anon_sym_decimal,
      anon_sym_time,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_list,
      anon_sym_value,
      anon_sym_keyset,
      anon_sym_guard,
  [2948] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(394), 1,
      anon_sym_LBRACK,
    ACTIONS(396), 1,
      anon_sym_LBRACE,
    STATE(143), 1,
      sym__parametrized_object,
    STATE(144), 1,
      sym__parametrized_list,
    STATE(145), 1,
      sym_type_identifier,
    ACTIONS(398), 2,
      anon_sym_object,
      anon_sym_table,
    ACTIONS(400), 9,
      anon_sym_integer,
      anon_sym_decimal,
      anon_sym_time,
      anon_sym_bool,
      anon_sym_string,
      anon_sym_list,
      anon_sym_value,
      anon_sym_keyset,
      anon_sym_guard,
  [2982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
    ACTIONS(361), 8,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
  [3006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(404), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(402), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(406), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3052] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(410), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(416), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(414), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(410), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3121] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_reference_repeat1,
    ACTIONS(229), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(111), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3148] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(418), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(424), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(422), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(428), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(426), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(430), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(436), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(434), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3263] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(440), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(438), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(444), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(442), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3309] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_DOT,
    STATE(98), 1,
      aux_sym_reference_repeat1,
    ACTIONS(349), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(351), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(448), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(446), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(450), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(454), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(460), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(458), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(464), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(462), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3451] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(468), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(466), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(472), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(470), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3497] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(476), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(474), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(480), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(478), 8,
      sym_integer,
      sym_boolean,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [3543] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(482), 1,
      anon_sym_DOT,
    STATE(98), 1,
      aux_sym_reference_repeat1,
    ACTIONS(359), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(361), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3570] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    STATE(105), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    ACTIONS(75), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(361), 11,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
  [3636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(487), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(485), 11,
      ts_builtin_sym_end,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3658] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_DOT,
    ACTIONS(489), 1,
      anon_sym_COLON,
    STATE(88), 1,
      aux_sym_reference_repeat1,
    STATE(296), 1,
      sym_type_annotation,
    ACTIONS(229), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(111), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3688] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    ACTIONS(491), 1,
      anon_sym_RPAREN,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(393), 1,
      sym__doc_or_meta,
  [3734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(495), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(493), 11,
      ts_builtin_sym_end,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3756] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 1,
      sym_string,
    ACTIONS(500), 1,
      anon_sym_ATdoc,
    ACTIONS(503), 1,
      anon_sym_ATmodel,
    ACTIONS(506), 1,
      anon_sym_ATmanaged,
    ACTIONS(509), 1,
      anon_sym_ATevent,
    ACTIONS(512), 1,
      anon_sym_AT,
    STATE(105), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    ACTIONS(79), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3800] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_string,
    ACTIONS(59), 1,
      anon_sym_ATdoc,
    ACTIONS(61), 1,
      anon_sym_ATmodel,
    ACTIONS(63), 1,
      anon_sym_ATmanaged,
    ACTIONS(65), 1,
      anon_sym_ATevent,
    ACTIONS(67), 1,
      anon_sym_AT,
    ACTIONS(515), 1,
      anon_sym_RPAREN,
    STATE(99), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(169), 1,
      sym_doc,
    STATE(170), 1,
      sym_model,
    STATE(171), 1,
      sym_managed,
    STATE(174), 1,
      sym_event,
    STATE(176), 1,
      sym_meta,
    STATE(404), 1,
      sym__doc_or_meta,
  [3846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(478), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(480), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3867] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      sym_atom,
    ACTIONS(517), 1,
      sym_string,
    ACTIONS(520), 1,
      anon_sym_ATdoc,
    ACTIONS(523), 1,
      anon_sym_ATmodel,
    ACTIONS(526), 1,
      anon_sym_ATmanaged,
    ACTIONS(529), 1,
      anon_sym_ATevent,
    ACTIONS(532), 1,
      anon_sym_AT,
    STATE(108), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(193), 1,
      sym_doc,
    STATE(194), 1,
      sym_model,
    STATE(195), 1,
      sym_managed,
    STATE(196), 1,
      sym_event,
    STATE(197), 1,
      sym_meta,
  [3910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(474), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(476), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(462), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(464), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(466), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(468), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(535), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(537), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [3994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(539), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(541), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4015] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(543), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(545), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(547), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(549), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(456), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4078] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      sym_atom,
    ACTIONS(337), 1,
      sym_string,
    ACTIONS(339), 1,
      anon_sym_ATdoc,
    ACTIONS(341), 1,
      anon_sym_ATmodel,
    ACTIONS(343), 1,
      anon_sym_ATmanaged,
    ACTIONS(345), 1,
      anon_sym_ATevent,
    ACTIONS(347), 1,
      anon_sym_AT,
    STATE(108), 1,
      aux_sym__doc_or_meta_repeat1,
    STATE(193), 1,
      sym_doc,
    STATE(194), 1,
      sym_model,
    STATE(195), 1,
      sym_managed,
    STATE(196), 1,
      sym_event,
    STATE(197), 1,
      sym_meta,
  [4121] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(113), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_reference_repeat1,
    ACTIONS(229), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(111), 8,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(551), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(553), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(470), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(472), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4188] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(557), 10,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LPAREN,
    ACTIONS(559), 1,
      anon_sym_RPAREN,
    STATE(123), 10,
      sym_bless,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_deftable,
      sym_use,
      sym_implements,
      aux_sym_module_repeat1,
  [4231] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(564), 1,
      anon_sym_RPAREN,
    STATE(123), 10,
      sym_bless,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_deftable,
      sym_use,
      sym_implements,
      aux_sym_module_repeat1,
  [4253] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(570), 1,
      anon_sym_RBRACK,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    STATE(266), 1,
      aux_sym_list_repeat2,
    ACTIONS(566), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(568), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4279] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(575), 1,
      anon_sym_RBRACK,
    STATE(273), 1,
      aux_sym_list_repeat2,
    ACTIONS(566), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(568), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4305] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(578), 1,
      anon_sym_RBRACK,
    STATE(279), 1,
      aux_sym_list_repeat2,
    ACTIONS(566), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(568), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4331] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(581), 1,
      anon_sym_RBRACK,
    STATE(277), 1,
      aux_sym_list_repeat2,
    ACTIONS(566), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(568), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4357] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LPAREN,
    ACTIONS(584), 1,
      anon_sym_RPAREN,
    STATE(122), 10,
      sym_bless,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_deftable,
      sym_use,
      sym_implements,
      aux_sym_module_repeat1,
  [4379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(55), 1,
      anon_sym_LPAREN,
    ACTIONS(586), 1,
      anon_sym_RPAREN,
    STATE(123), 10,
      sym_bless,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_deftable,
      sym_use,
      sym_implements,
      aux_sym_module_repeat1,
  [4401] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(588), 1,
      anon_sym_DOT,
    STATE(131), 1,
      aux_sym_reference_repeat1,
    ACTIONS(351), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(349), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4424] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(590), 1,
      anon_sym_DOT,
    STATE(131), 1,
      aux_sym_reference_repeat1,
    ACTIONS(361), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(359), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4447] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(588), 1,
      anon_sym_DOT,
    STATE(130), 1,
      aux_sym_reference_repeat1,
    ACTIONS(111), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(229), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4470] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_COLON,
    STATE(157), 1,
      sym_type_annotation,
    ACTIONS(593), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(595), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(458), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(460), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4511] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(406), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(408), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(599), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(601), 7,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [4547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 4,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
    ACTIONS(359), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4565] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_LPAREN,
    STATE(138), 1,
      aux_sym_cond_repeat1,
    ACTIONS(603), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(605), 5,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [4587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(599), 1,
      anon_sym_AT,
    ACTIONS(601), 8,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [4604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(476), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(474), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4621] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(614), 1,
      anon_sym_LBRACE,
    ACTIONS(610), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(612), 5,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
  [4640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(610), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(612), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4657] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(616), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(618), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4674] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(616), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(618), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4691] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(620), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(622), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(624), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(626), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(628), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(630), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(632), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(634), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 1,
      anon_sym_AT,
    ACTIONS(636), 1,
      anon_sym_DOT,
    STATE(150), 1,
      aux_sym_reference_repeat1,
    ACTIONS(351), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [4780] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 1,
      anon_sym_AT,
    ACTIONS(638), 1,
      anon_sym_DOT,
    STATE(150), 1,
      aux_sym_reference_repeat1,
    ACTIONS(361), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [4801] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LPAREN,
    ACTIONS(641), 1,
      anon_sym_RPAREN,
    STATE(154), 7,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_use,
      aux_sym_interface_repeat1,
  [4820] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 1,
      sym_atom,
    ACTIONS(436), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(434), 5,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4839] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_RPAREN,
    STATE(154), 7,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_use,
      aux_sym_interface_repeat1,
  [4858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(647), 1,
      anon_sym_LPAREN,
    ACTIONS(650), 1,
      anon_sym_RPAREN,
    STATE(154), 7,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_use,
      aux_sym_interface_repeat1,
  [4877] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(652), 1,
      anon_sym_bless,
    ACTIONS(654), 1,
      anon_sym_defun,
    ACTIONS(656), 1,
      anon_sym_defcap,
    ACTIONS(658), 1,
      anon_sym_defconst,
    ACTIONS(660), 1,
      anon_sym_defpact,
    ACTIONS(662), 1,
      anon_sym_defschema,
    ACTIONS(664), 1,
      anon_sym_deftable,
    ACTIONS(666), 1,
      anon_sym_use,
    ACTIONS(668), 1,
      anon_sym_implements,
  [4908] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_LPAREN,
    ACTIONS(670), 1,
      anon_sym_RPAREN,
    STATE(153), 7,
      sym_defun,
      sym_defcap,
      sym_defconst,
      sym_defpact,
      sym_defschema,
      sym_use,
      aux_sym_interface_repeat1,
  [4927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(672), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(674), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(676), 3,
      sym_integer,
      sym_boolean,
      sym_atom,
    ACTIONS(678), 6,
      sym_decimal,
      sym_string,
      sym_symbol,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
  [4961] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(229), 1,
      anon_sym_AT,
    ACTIONS(636), 1,
      anon_sym_DOT,
    STATE(149), 1,
      aux_sym_reference_repeat1,
    ACTIONS(111), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [4982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(454), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [4999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(464), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(462), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(468), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(466), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5033] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(480), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(478), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(472), 3,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(470), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(450), 1,
      anon_sym_AT,
    ACTIONS(452), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5083] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(406), 1,
      anon_sym_AT,
    ACTIONS(408), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(446), 1,
      anon_sym_AT,
    ACTIONS(448), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5115] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(680), 1,
      sym_atom,
    ACTIONS(682), 1,
      anon_sym_RPAREN,
    ACTIONS(686), 1,
      anon_sym_cond,
    STATE(24), 1,
      sym_reference,
    ACTIONS(684), 2,
      anon_sym_let,
      anon_sym_let_STAR,
    STATE(254), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [5139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(402), 1,
      anon_sym_AT,
    ACTIONS(404), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5155] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(414), 1,
      anon_sym_AT,
    ACTIONS(416), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(426), 1,
      anon_sym_AT,
    ACTIONS(428), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(690), 1,
      anon_sym_AT,
    ACTIONS(688), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5203] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(438), 1,
      anon_sym_AT,
    ACTIONS(440), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(418), 1,
      anon_sym_AT,
    ACTIONS(420), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_AT,
    ACTIONS(444), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(422), 1,
      anon_sym_AT,
    ACTIONS(424), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(410), 1,
      anon_sym_AT,
    ACTIONS(412), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(430), 1,
      anon_sym_AT,
    ACTIONS(432), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5299] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LPAREN,
    ACTIONS(692), 1,
      ts_builtin_sym_end,
    STATE(180), 6,
      sym_s_expression,
      sym_namespace,
      sym_use,
      sym_interface,
      sym_module,
      aux_sym_source_file_repeat1,
  [5317] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(694), 1,
      ts_builtin_sym_end,
    ACTIONS(696), 1,
      anon_sym_LPAREN,
    STATE(180), 6,
      sym_s_expression,
      sym_namespace,
      sym_use,
      sym_interface,
      sym_module,
      aux_sym_source_file_repeat1,
  [5335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(359), 1,
      anon_sym_AT,
    ACTIONS(361), 7,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(458), 1,
      anon_sym_AT,
    ACTIONS(460), 7,
      sym_string,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(436), 1,
      sym_string,
    ACTIONS(434), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(551), 1,
      anon_sym_AT,
    ACTIONS(553), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 1,
      anon_sym_AT,
    ACTIONS(557), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(539), 1,
      anon_sym_AT,
    ACTIONS(541), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(487), 1,
      anon_sym_AT,
    ACTIONS(485), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5442] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(535), 1,
      anon_sym_AT,
    ACTIONS(537), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(601), 1,
      sym_string,
    ACTIONS(599), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(470), 1,
      anon_sym_AT,
    ACTIONS(472), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 1,
      sym_string,
    ACTIONS(410), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(474), 1,
      anon_sym_AT,
    ACTIONS(476), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(404), 1,
      sym_string,
    ACTIONS(402), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(416), 1,
      sym_string,
    ACTIONS(414), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(428), 1,
      sym_string,
    ACTIONS(426), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 1,
      sym_string,
    ACTIONS(418), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(424), 1,
      sym_string,
    ACTIONS(422), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 1,
      sym_string,
    ACTIONS(450), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 1,
      anon_sym_AT,
    ACTIONS(456), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(478), 1,
      anon_sym_AT,
    ACTIONS(480), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(495), 1,
      anon_sym_AT,
    ACTIONS(493), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5652] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 1,
      sym_string,
    ACTIONS(430), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(543), 1,
      anon_sym_AT,
    ACTIONS(545), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5682] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(440), 1,
      sym_string,
    ACTIONS(438), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5697] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(444), 1,
      sym_string,
    ACTIONS(442), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5712] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 1,
      anon_sym_cond,
    ACTIONS(699), 1,
      sym_atom,
    ACTIONS(701), 1,
      anon_sym_LPAREN,
    STATE(24), 1,
      sym_reference,
    STATE(67), 1,
      sym_s_expression,
    ACTIONS(684), 2,
      anon_sym_let,
      anon_sym_let_STAR,
  [5735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(462), 1,
      anon_sym_AT,
    ACTIONS(464), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5750] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(466), 1,
      anon_sym_AT,
    ACTIONS(468), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(448), 1,
      sym_string,
    ACTIONS(446), 6,
      sym_atom,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
      anon_sym_AT,
  [5780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(547), 1,
      anon_sym_AT,
    ACTIONS(549), 6,
      sym_string,
      anon_sym_RPAREN,
      anon_sym_ATdoc,
      anon_sym_ATmodel,
      anon_sym_ATmanaged,
      anon_sym_ATevent,
  [5795] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(705), 1,
      anon_sym_RBRACE,
    STATE(302), 1,
      sym__property_name,
    ACTIONS(703), 2,
      sym_string,
      sym_symbol,
    STATE(264), 2,
      sym_pair,
      sym_bind_pair,
  [5813] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 1,
      anon_sym_RBRACE,
    STATE(302), 1,
      sym__property_name,
    ACTIONS(703), 2,
      sym_string,
      sym_symbol,
    STATE(276), 2,
      sym_pair,
      sym_bind_pair,
  [5831] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(654), 1,
      anon_sym_defun,
    ACTIONS(656), 1,
      anon_sym_defcap,
    ACTIONS(658), 1,
      anon_sym_defconst,
    ACTIONS(660), 1,
      anon_sym_defpact,
    ACTIONS(662), 1,
      anon_sym_defschema,
    ACTIONS(666), 1,
      anon_sym_use,
  [5853] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(699), 1,
      sym_atom,
    ACTIONS(709), 1,
      anon_sym_namespace,
    ACTIONS(711), 1,
      anon_sym_use,
    ACTIONS(713), 1,
      anon_sym_interface,
    ACTIONS(715), 1,
      anon_sym_module,
    STATE(24), 1,
      sym_reference,
  [5875] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(717), 1,
      anon_sym_RBRACE,
    STATE(302), 1,
      sym__property_name,
    ACTIONS(703), 2,
      sym_string,
      sym_symbol,
    STATE(265), 2,
      sym_pair,
      sym_bind_pair,
  [5893] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(686), 1,
      anon_sym_cond,
    ACTIONS(699), 1,
      sym_atom,
    STATE(24), 1,
      sym_reference,
    ACTIONS(684), 2,
      anon_sym_let,
      anon_sym_let_STAR,
  [5910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(302), 1,
      sym__property_name,
    ACTIONS(703), 2,
      sym_string,
      sym_symbol,
    STATE(349), 2,
      sym_pair,
      sym_bind_pair,
  [5925] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(719), 1,
      anon_sym_RPAREN,
    STATE(224), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [5940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(721), 1,
      anon_sym_RBRACK,
    ACTIONS(723), 1,
      anon_sym_LPAREN,
    STATE(219), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [5955] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(726), 1,
      anon_sym_RPAREN,
    STATE(229), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [5970] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(728), 1,
      anon_sym_RPAREN,
    STATE(224), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [5985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_RBRACK,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    STATE(226), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_RPAREN,
    STATE(224), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [6015] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(739), 1,
      anon_sym_RPAREN,
    STATE(224), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [6030] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(741), 1,
      anon_sym_RPAREN,
    STATE(223), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [6045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_RBRACK,
    STATE(219), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    ACTIONS(745), 1,
      anon_sym_RBRACK,
    STATE(228), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6075] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    ACTIONS(747), 1,
      anon_sym_RBRACK,
    STATE(219), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6090] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(279), 1,
      anon_sym_LPAREN,
    ACTIONS(749), 1,
      anon_sym_RPAREN,
    STATE(224), 3,
      sym_step,
      sym_step_with_rollback,
      aux_sym_defpact_repeat1,
  [6105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 1,
      anon_sym_LBRACE,
    ACTIONS(612), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6118] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    ACTIONS(753), 1,
      anon_sym_RBRACK,
    STATE(232), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_LPAREN,
    ACTIONS(755), 1,
      anon_sym_RBRACK,
    STATE(219), 3,
      sym_s_expression,
      sym_defproperty,
      aux_sym_model_repeat1,
  [6148] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(699), 1,
      sym_atom,
    ACTIONS(759), 1,
      anon_sym_cond,
    STATE(39), 1,
      sym_reference,
    ACTIONS(757), 2,
      anon_sym_let,
      anon_sym_let_STAR,
  [6165] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 1,
      sym_atom,
    ACTIONS(763), 1,
      anon_sym_RPAREN,
    STATE(246), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6179] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(765), 1,
      anon_sym_LPAREN,
    ACTIONS(768), 1,
      anon_sym_RPAREN,
    STATE(235), 2,
      sym_let_bind_pair,
      aux_sym_let_binding_repeat1,
  [6193] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(772), 1,
      anon_sym_RPAREN,
    STATE(258), 2,
      sym_let_bind_pair,
      aux_sym_let_binding_repeat1,
  [6207] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(774), 1,
      sym_atom,
    ACTIONS(777), 1,
      anon_sym_RPAREN,
    STATE(237), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(626), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(630), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6241] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_COLON,
    ACTIONS(779), 1,
      anon_sym_LPAREN,
    STATE(5), 1,
      sym_parameter_list,
    STATE(293), 1,
      sym_type_annotation,
  [6257] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_type_annotation,
    ACTIONS(781), 2,
      anon_sym_RPAREN,
      sym_atom,
  [6271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 1,
      sym_atom,
    STATE(375), 1,
      sym_schema_field_list,
    STATE(248), 2,
      sym_schema_field,
      aux_sym_schema_field_list_repeat1,
  [6285] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 1,
      sym_atom,
    ACTIONS(785), 1,
      anon_sym_RPAREN,
    STATE(247), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6299] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_COLON,
    ACTIONS(787), 1,
      anon_sym_LPAREN,
    STATE(54), 1,
      sym_parameter_list,
    STATE(301), 1,
      sym_type_annotation,
  [6315] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_COLON,
    STATE(296), 1,
      sym_type_annotation,
    ACTIONS(789), 2,
      anon_sym_RPAREN,
      sym_atom,
  [6329] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 1,
      sym_atom,
    ACTIONS(791), 1,
      anon_sym_RPAREN,
    STATE(237), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6343] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 1,
      sym_atom,
    ACTIONS(793), 1,
      anon_sym_RPAREN,
    STATE(237), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6357] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 1,
      sym_atom,
    ACTIONS(795), 1,
      anon_sym_RPAREN,
    STATE(253), 2,
      sym_schema_field,
      aux_sym_schema_field_list_repeat1,
  [6371] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(797), 1,
      sym_string,
    ACTIONS(799), 1,
      anon_sym_RPAREN,
    STATE(368), 1,
      sym_list,
  [6387] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(612), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6397] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(634), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      anon_sym_COLON,
    ACTIONS(779), 1,
      anon_sym_LPAREN,
    STATE(2), 1,
      sym_parameter_list,
    STATE(295), 1,
      sym_type_annotation,
  [6423] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(801), 1,
      sym_atom,
    ACTIONS(804), 1,
      anon_sym_RPAREN,
    STATE(253), 2,
      sym_schema_field,
      aux_sym_schema_field_list_repeat1,
  [6437] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(761), 1,
      sym_atom,
    ACTIONS(806), 1,
      anon_sym_RPAREN,
    STATE(237), 2,
      sym_parameter,
      aux_sym_parameter_list_repeat1,
  [6451] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(618), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(618), 4,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6471] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(808), 1,
      anon_sym_RPAREN,
    STATE(259), 2,
      sym_let_bind_pair,
      aux_sym_let_binding_repeat1,
  [6485] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(810), 1,
      anon_sym_RPAREN,
    STATE(235), 2,
      sym_let_bind_pair,
      aux_sym_let_binding_repeat1,
  [6499] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(770), 1,
      anon_sym_LPAREN,
    ACTIONS(812), 1,
      anon_sym_RPAREN,
    STATE(235), 2,
      sym_let_bind_pair,
      aux_sym_let_binding_repeat1,
  [6513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(622), 3,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_atom,
  [6522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(816), 1,
      anon_sym_RBRACE,
    STATE(278), 1,
      aux_sym_object_repeat1,
  [6535] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(818), 1,
      anon_sym_RBRACE,
    STATE(278), 1,
      aux_sym_object_repeat1,
  [6548] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(820), 3,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6557] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(822), 1,
      anon_sym_RBRACE,
    STATE(267), 1,
      aux_sym_object_repeat1,
  [6570] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(824), 1,
      anon_sym_RBRACE,
    STATE(261), 1,
      aux_sym_object_repeat1,
  [6583] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(826), 1,
      anon_sym_RBRACK,
    STATE(275), 1,
      aux_sym_list_repeat2,
  [6596] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(828), 1,
      anon_sym_RBRACE,
    STATE(278), 1,
      aux_sym_object_repeat1,
  [6609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(830), 3,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6618] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(832), 3,
      sym_string,
      sym_symbol,
      sym_atom,
  [6627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(834), 3,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6636] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(699), 1,
      sym_atom,
    ACTIONS(836), 1,
      anon_sym_defproperty,
    STATE(24), 1,
      sym_reference,
  [6649] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(838), 1,
      anon_sym_RBRACE,
    STATE(274), 1,
      aux_sym_object_repeat1,
  [6662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(840), 1,
      anon_sym_RBRACK,
    STATE(275), 1,
      aux_sym_list_repeat2,
  [6675] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(842), 1,
      anon_sym_RBRACE,
    STATE(278), 1,
      aux_sym_object_repeat1,
  [6688] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(844), 1,
      anon_sym_RBRACK,
    ACTIONS(846), 1,
      anon_sym_COMMA,
    STATE(275), 1,
      aux_sym_list_repeat2,
  [6701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(814), 1,
      anon_sym_COMMA,
    ACTIONS(849), 1,
      anon_sym_RBRACE,
    STATE(262), 1,
      aux_sym_object_repeat1,
  [6714] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(851), 1,
      anon_sym_RBRACK,
    STATE(275), 1,
      aux_sym_list_repeat2,
  [6727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(853), 1,
      anon_sym_COMMA,
    ACTIONS(856), 1,
      anon_sym_RBRACE,
    STATE(278), 1,
      aux_sym_object_repeat1,
  [6740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 1,
      anon_sym_COMMA,
    ACTIONS(858), 1,
      anon_sym_RBRACK,
    STATE(275), 1,
      aux_sym_list_repeat2,
  [6753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(860), 2,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
  [6761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(862), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [6769] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(864), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(24), 1,
      sym_reference,
  [6787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(868), 1,
      anon_sym_step,
    ACTIONS(870), 1,
      anon_sym_step_DASHwith_DASHrollback,
  [6797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(872), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    STATE(373), 1,
      sym_list,
  [6815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(874), 1,
      anon_sym_COLON,
    ACTIONS(876), 1,
      anon_sym_COLON_EQ,
  [6825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(878), 2,
      anon_sym_RPAREN,
      sym_atom,
  [6833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(882), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(884), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(886), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [6865] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 1,
      anon_sym_LPAREN,
    STATE(3), 1,
      sym_parameter_list,
  [6875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(888), 2,
      sym_string,
      sym_symbol,
  [6883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 1,
      anon_sym_LPAREN,
    STATE(4), 1,
      sym_parameter_list,
  [6893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(890), 2,
      anon_sym_RPAREN,
      sym_atom,
  [6901] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(249), 1,
      sym_reference,
  [6911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [6919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(388), 1,
      sym_reference,
  [6929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(894), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 1,
      anon_sym_LPAREN,
    STATE(50), 1,
      sym_parameter_list,
  [6947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(896), 1,
      anon_sym_COLON,
    ACTIONS(898), 1,
      anon_sym_COLON_EQ,
  [6957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(900), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(902), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6973] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(904), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6981] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(906), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [6989] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(908), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [6997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(910), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(912), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(914), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(916), 1,
      sym_atom,
    STATE(10), 1,
      sym__def_name,
  [7031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(918), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [7039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(920), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(926), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [7071] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(928), 2,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
  [7079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(930), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(932), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [7095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(934), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7103] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(936), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(938), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(940), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(942), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7143] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(946), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(948), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(950), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [7167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(952), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(701), 1,
      anon_sym_LPAREN,
    STATE(67), 1,
      sym_s_expression,
  [7185] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(954), 2,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
  [7193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(956), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(958), 1,
      sym_atom,
    STATE(240), 1,
      sym__def_name,
  [7211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(844), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [7219] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(960), 2,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
  [7227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(389), 1,
      sym_reference,
  [7237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(962), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(964), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7253] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(966), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7261] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(968), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(958), 1,
      sym_atom,
    STATE(252), 1,
      sym__def_name,
  [7279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(970), 2,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
  [7287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(916), 1,
      sym_atom,
    STATE(68), 1,
      sym__def_name,
  [7297] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(974), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7313] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(976), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(980), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(856), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [7345] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(958), 1,
      sym_atom,
    STATE(244), 1,
      sym__def_name,
  [7355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(982), 1,
      sym_atom,
    STATE(63), 1,
      sym__def_name,
  [7365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(958), 1,
      sym_atom,
    STATE(7), 1,
      sym__def_name,
  [7375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(984), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [7383] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(986), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [7391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(988), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [7399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(990), 1,
      sym_atom,
    STATE(56), 1,
      sym_let_variable,
  [7409] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(378), 1,
      sym_reference,
  [7419] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_atom,
    STATE(379), 1,
      sym_reference,
  [7429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(958), 1,
      sym_atom,
    STATE(405), 1,
      sym__def_name,
  [7439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(992), 1,
      sym_string,
  [7446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(994), 1,
      anon_sym_RPAREN,
  [7453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(996), 1,
      sym_atom,
  [7460] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(998), 1,
      anon_sym_LPAREN,
  [7467] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1000), 1,
      anon_sym_RPAREN,
  [7474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1002), 1,
      anon_sym_LBRACE,
  [7481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1004), 1,
      anon_sym_RPAREN,
  [7488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1006), 1,
      anon_sym_RPAREN,
  [7495] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1008), 1,
      anon_sym_RPAREN,
  [7502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1010), 1,
      anon_sym_RPAREN,
  [7509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1012), 1,
      anon_sym_RPAREN,
  [7516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_RBRACE,
  [7523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1016), 1,
      sym_boolean,
  [7530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1018), 1,
      anon_sym_RPAREN,
  [7537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1020), 1,
      sym_atom,
  [7544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1022), 1,
      anon_sym_RPAREN,
  [7551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1024), 1,
      anon_sym_RPAREN,
  [7558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 1,
      anon_sym_RBRACK,
  [7565] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 1,
      anon_sym_RBRACE,
  [7572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1030), 1,
      anon_sym_RBRACE,
  [7579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1032), 1,
      sym_atom,
  [7586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_RBRACK,
  [7593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1036), 1,
      sym_string,
  [7600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1038), 1,
      sym_string,
  [7607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1040), 1,
      sym_atom,
  [7614] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1042), 1,
      sym_atom,
  [7621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 1,
      anon_sym_RPAREN,
  [7628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1046), 1,
      anon_sym_LBRACK,
  [7635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1048), 1,
      anon_sym_RBRACE,
  [7642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 1,
      anon_sym_RBRACE,
  [7649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1052), 1,
      anon_sym_RPAREN,
  [7656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1054), 1,
      sym_atom,
  [7663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1056), 1,
      anon_sym_RPAREN,
  [7670] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1058), 1,
      anon_sym_RPAREN,
  [7677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1060), 1,
      sym_atom,
  [7684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1062), 1,
      sym_string,
  [7691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1064), 1,
      anon_sym_RPAREN,
  [7698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1066), 1,
      anon_sym_RPAREN,
  [7705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1068), 1,
      ts_builtin_sym_end,
  [7712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1070), 1,
      sym_atom,
  [7719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1072), 1,
      anon_sym_LBRACK,
  [7726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1074), 1,
      sym_atom,
  [7733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1076), 1,
      anon_sym_RPAREN,
  [7740] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      anon_sym_RPAREN,
  [7747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1080), 1,
      anon_sym_RPAREN,
  [7754] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1082), 1,
      anon_sym_COLON,
  [7761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1084), 1,
      sym_atom,
  [7768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1086), 1,
      sym_boolean,
  [7775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1088), 1,
      anon_sym_LBRACK,
  [7782] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1090), 1,
      anon_sym_LPAREN,
  [7789] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1092), 1,
      sym_boolean,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 77,
  [SMALL_STATE(4)] = 154,
  [SMALL_STATE(5)] = 231,
  [SMALL_STATE(6)] = 308,
  [SMALL_STATE(7)] = 369,
  [SMALL_STATE(8)] = 427,
  [SMALL_STATE(9)] = 478,
  [SMALL_STATE(10)] = 531,
  [SMALL_STATE(11)] = 573,
  [SMALL_STATE(12)] = 617,
  [SMALL_STATE(13)] = 657,
  [SMALL_STATE(14)] = 696,
  [SMALL_STATE(15)] = 735,
  [SMALL_STATE(16)] = 774,
  [SMALL_STATE(17)] = 813,
  [SMALL_STATE(18)] = 852,
  [SMALL_STATE(19)] = 891,
  [SMALL_STATE(20)] = 930,
  [SMALL_STATE(21)] = 969,
  [SMALL_STATE(22)] = 1008,
  [SMALL_STATE(23)] = 1047,
  [SMALL_STATE(24)] = 1086,
  [SMALL_STATE(25)] = 1125,
  [SMALL_STATE(26)] = 1164,
  [SMALL_STATE(27)] = 1203,
  [SMALL_STATE(28)] = 1242,
  [SMALL_STATE(29)] = 1281,
  [SMALL_STATE(30)] = 1320,
  [SMALL_STATE(31)] = 1359,
  [SMALL_STATE(32)] = 1398,
  [SMALL_STATE(33)] = 1439,
  [SMALL_STATE(34)] = 1478,
  [SMALL_STATE(35)] = 1517,
  [SMALL_STATE(36)] = 1556,
  [SMALL_STATE(37)] = 1589,
  [SMALL_STATE(38)] = 1628,
  [SMALL_STATE(39)] = 1657,
  [SMALL_STATE(40)] = 1696,
  [SMALL_STATE(41)] = 1737,
  [SMALL_STATE(42)] = 1776,
  [SMALL_STATE(43)] = 1815,
  [SMALL_STATE(44)] = 1854,
  [SMALL_STATE(45)] = 1893,
  [SMALL_STATE(46)] = 1932,
  [SMALL_STATE(47)] = 1971,
  [SMALL_STATE(48)] = 2012,
  [SMALL_STATE(49)] = 2051,
  [SMALL_STATE(50)] = 2090,
  [SMALL_STATE(51)] = 2144,
  [SMALL_STATE(52)] = 2182,
  [SMALL_STATE(53)] = 2220,
  [SMALL_STATE(54)] = 2258,
  [SMALL_STATE(55)] = 2312,
  [SMALL_STATE(56)] = 2350,
  [SMALL_STATE(57)] = 2385,
  [SMALL_STATE(58)] = 2420,
  [SMALL_STATE(59)] = 2455,
  [SMALL_STATE(60)] = 2490,
  [SMALL_STATE(61)] = 2525,
  [SMALL_STATE(62)] = 2560,
  [SMALL_STATE(63)] = 2595,
  [SMALL_STATE(64)] = 2648,
  [SMALL_STATE(65)] = 2677,
  [SMALL_STATE(66)] = 2712,
  [SMALL_STATE(67)] = 2741,
  [SMALL_STATE(68)] = 2776,
  [SMALL_STATE(69)] = 2811,
  [SMALL_STATE(70)] = 2846,
  [SMALL_STATE(71)] = 2880,
  [SMALL_STATE(72)] = 2914,
  [SMALL_STATE(73)] = 2948,
  [SMALL_STATE(74)] = 2982,
  [SMALL_STATE(75)] = 3006,
  [SMALL_STATE(76)] = 3029,
  [SMALL_STATE(77)] = 3052,
  [SMALL_STATE(78)] = 3075,
  [SMALL_STATE(79)] = 3098,
  [SMALL_STATE(80)] = 3121,
  [SMALL_STATE(81)] = 3148,
  [SMALL_STATE(82)] = 3171,
  [SMALL_STATE(83)] = 3194,
  [SMALL_STATE(84)] = 3217,
  [SMALL_STATE(85)] = 3240,
  [SMALL_STATE(86)] = 3263,
  [SMALL_STATE(87)] = 3286,
  [SMALL_STATE(88)] = 3309,
  [SMALL_STATE(89)] = 3336,
  [SMALL_STATE(90)] = 3359,
  [SMALL_STATE(91)] = 3382,
  [SMALL_STATE(92)] = 3405,
  [SMALL_STATE(93)] = 3428,
  [SMALL_STATE(94)] = 3451,
  [SMALL_STATE(95)] = 3474,
  [SMALL_STATE(96)] = 3497,
  [SMALL_STATE(97)] = 3520,
  [SMALL_STATE(98)] = 3543,
  [SMALL_STATE(99)] = 3570,
  [SMALL_STATE(100)] = 3614,
  [SMALL_STATE(101)] = 3636,
  [SMALL_STATE(102)] = 3658,
  [SMALL_STATE(103)] = 3688,
  [SMALL_STATE(104)] = 3734,
  [SMALL_STATE(105)] = 3756,
  [SMALL_STATE(106)] = 3800,
  [SMALL_STATE(107)] = 3846,
  [SMALL_STATE(108)] = 3867,
  [SMALL_STATE(109)] = 3910,
  [SMALL_STATE(110)] = 3931,
  [SMALL_STATE(111)] = 3952,
  [SMALL_STATE(112)] = 3973,
  [SMALL_STATE(113)] = 3994,
  [SMALL_STATE(114)] = 4015,
  [SMALL_STATE(115)] = 4036,
  [SMALL_STATE(116)] = 4057,
  [SMALL_STATE(117)] = 4078,
  [SMALL_STATE(118)] = 4121,
  [SMALL_STATE(119)] = 4146,
  [SMALL_STATE(120)] = 4167,
  [SMALL_STATE(121)] = 4188,
  [SMALL_STATE(122)] = 4209,
  [SMALL_STATE(123)] = 4231,
  [SMALL_STATE(124)] = 4253,
  [SMALL_STATE(125)] = 4279,
  [SMALL_STATE(126)] = 4305,
  [SMALL_STATE(127)] = 4331,
  [SMALL_STATE(128)] = 4357,
  [SMALL_STATE(129)] = 4379,
  [SMALL_STATE(130)] = 4401,
  [SMALL_STATE(131)] = 4424,
  [SMALL_STATE(132)] = 4447,
  [SMALL_STATE(133)] = 4470,
  [SMALL_STATE(134)] = 4493,
  [SMALL_STATE(135)] = 4511,
  [SMALL_STATE(136)] = 4529,
  [SMALL_STATE(137)] = 4547,
  [SMALL_STATE(138)] = 4565,
  [SMALL_STATE(139)] = 4587,
  [SMALL_STATE(140)] = 4604,
  [SMALL_STATE(141)] = 4621,
  [SMALL_STATE(142)] = 4640,
  [SMALL_STATE(143)] = 4657,
  [SMALL_STATE(144)] = 4674,
  [SMALL_STATE(145)] = 4691,
  [SMALL_STATE(146)] = 4708,
  [SMALL_STATE(147)] = 4725,
  [SMALL_STATE(148)] = 4742,
  [SMALL_STATE(149)] = 4759,
  [SMALL_STATE(150)] = 4780,
  [SMALL_STATE(151)] = 4801,
  [SMALL_STATE(152)] = 4820,
  [SMALL_STATE(153)] = 4839,
  [SMALL_STATE(154)] = 4858,
  [SMALL_STATE(155)] = 4877,
  [SMALL_STATE(156)] = 4908,
  [SMALL_STATE(157)] = 4927,
  [SMALL_STATE(158)] = 4944,
  [SMALL_STATE(159)] = 4961,
  [SMALL_STATE(160)] = 4982,
  [SMALL_STATE(161)] = 4999,
  [SMALL_STATE(162)] = 5016,
  [SMALL_STATE(163)] = 5033,
  [SMALL_STATE(164)] = 5050,
  [SMALL_STATE(165)] = 5067,
  [SMALL_STATE(166)] = 5083,
  [SMALL_STATE(167)] = 5099,
  [SMALL_STATE(168)] = 5115,
  [SMALL_STATE(169)] = 5139,
  [SMALL_STATE(170)] = 5155,
  [SMALL_STATE(171)] = 5171,
  [SMALL_STATE(172)] = 5187,
  [SMALL_STATE(173)] = 5203,
  [SMALL_STATE(174)] = 5219,
  [SMALL_STATE(175)] = 5235,
  [SMALL_STATE(176)] = 5251,
  [SMALL_STATE(177)] = 5267,
  [SMALL_STATE(178)] = 5283,
  [SMALL_STATE(179)] = 5299,
  [SMALL_STATE(180)] = 5317,
  [SMALL_STATE(181)] = 5335,
  [SMALL_STATE(182)] = 5351,
  [SMALL_STATE(183)] = 5367,
  [SMALL_STATE(184)] = 5382,
  [SMALL_STATE(185)] = 5397,
  [SMALL_STATE(186)] = 5412,
  [SMALL_STATE(187)] = 5427,
  [SMALL_STATE(188)] = 5442,
  [SMALL_STATE(189)] = 5457,
  [SMALL_STATE(190)] = 5472,
  [SMALL_STATE(191)] = 5487,
  [SMALL_STATE(192)] = 5502,
  [SMALL_STATE(193)] = 5517,
  [SMALL_STATE(194)] = 5532,
  [SMALL_STATE(195)] = 5547,
  [SMALL_STATE(196)] = 5562,
  [SMALL_STATE(197)] = 5577,
  [SMALL_STATE(198)] = 5592,
  [SMALL_STATE(199)] = 5607,
  [SMALL_STATE(200)] = 5622,
  [SMALL_STATE(201)] = 5637,
  [SMALL_STATE(202)] = 5652,
  [SMALL_STATE(203)] = 5667,
  [SMALL_STATE(204)] = 5682,
  [SMALL_STATE(205)] = 5697,
  [SMALL_STATE(206)] = 5712,
  [SMALL_STATE(207)] = 5735,
  [SMALL_STATE(208)] = 5750,
  [SMALL_STATE(209)] = 5765,
  [SMALL_STATE(210)] = 5780,
  [SMALL_STATE(211)] = 5795,
  [SMALL_STATE(212)] = 5813,
  [SMALL_STATE(213)] = 5831,
  [SMALL_STATE(214)] = 5853,
  [SMALL_STATE(215)] = 5875,
  [SMALL_STATE(216)] = 5893,
  [SMALL_STATE(217)] = 5910,
  [SMALL_STATE(218)] = 5925,
  [SMALL_STATE(219)] = 5940,
  [SMALL_STATE(220)] = 5955,
  [SMALL_STATE(221)] = 5970,
  [SMALL_STATE(222)] = 5985,
  [SMALL_STATE(223)] = 6000,
  [SMALL_STATE(224)] = 6015,
  [SMALL_STATE(225)] = 6030,
  [SMALL_STATE(226)] = 6045,
  [SMALL_STATE(227)] = 6060,
  [SMALL_STATE(228)] = 6075,
  [SMALL_STATE(229)] = 6090,
  [SMALL_STATE(230)] = 6105,
  [SMALL_STATE(231)] = 6118,
  [SMALL_STATE(232)] = 6133,
  [SMALL_STATE(233)] = 6148,
  [SMALL_STATE(234)] = 6165,
  [SMALL_STATE(235)] = 6179,
  [SMALL_STATE(236)] = 6193,
  [SMALL_STATE(237)] = 6207,
  [SMALL_STATE(238)] = 6221,
  [SMALL_STATE(239)] = 6231,
  [SMALL_STATE(240)] = 6241,
  [SMALL_STATE(241)] = 6257,
  [SMALL_STATE(242)] = 6271,
  [SMALL_STATE(243)] = 6285,
  [SMALL_STATE(244)] = 6299,
  [SMALL_STATE(245)] = 6315,
  [SMALL_STATE(246)] = 6329,
  [SMALL_STATE(247)] = 6343,
  [SMALL_STATE(248)] = 6357,
  [SMALL_STATE(249)] = 6371,
  [SMALL_STATE(250)] = 6387,
  [SMALL_STATE(251)] = 6397,
  [SMALL_STATE(252)] = 6407,
  [SMALL_STATE(253)] = 6423,
  [SMALL_STATE(254)] = 6437,
  [SMALL_STATE(255)] = 6451,
  [SMALL_STATE(256)] = 6461,
  [SMALL_STATE(257)] = 6471,
  [SMALL_STATE(258)] = 6485,
  [SMALL_STATE(259)] = 6499,
  [SMALL_STATE(260)] = 6513,
  [SMALL_STATE(261)] = 6522,
  [SMALL_STATE(262)] = 6535,
  [SMALL_STATE(263)] = 6548,
  [SMALL_STATE(264)] = 6557,
  [SMALL_STATE(265)] = 6570,
  [SMALL_STATE(266)] = 6583,
  [SMALL_STATE(267)] = 6596,
  [SMALL_STATE(268)] = 6609,
  [SMALL_STATE(269)] = 6618,
  [SMALL_STATE(270)] = 6627,
  [SMALL_STATE(271)] = 6636,
  [SMALL_STATE(272)] = 6649,
  [SMALL_STATE(273)] = 6662,
  [SMALL_STATE(274)] = 6675,
  [SMALL_STATE(275)] = 6688,
  [SMALL_STATE(276)] = 6701,
  [SMALL_STATE(277)] = 6714,
  [SMALL_STATE(278)] = 6727,
  [SMALL_STATE(279)] = 6740,
  [SMALL_STATE(280)] = 6753,
  [SMALL_STATE(281)] = 6761,
  [SMALL_STATE(282)] = 6769,
  [SMALL_STATE(283)] = 6777,
  [SMALL_STATE(284)] = 6787,
  [SMALL_STATE(285)] = 6797,
  [SMALL_STATE(286)] = 6805,
  [SMALL_STATE(287)] = 6815,
  [SMALL_STATE(288)] = 6825,
  [SMALL_STATE(289)] = 6833,
  [SMALL_STATE(290)] = 6841,
  [SMALL_STATE(291)] = 6849,
  [SMALL_STATE(292)] = 6857,
  [SMALL_STATE(293)] = 6865,
  [SMALL_STATE(294)] = 6875,
  [SMALL_STATE(295)] = 6883,
  [SMALL_STATE(296)] = 6893,
  [SMALL_STATE(297)] = 6901,
  [SMALL_STATE(298)] = 6911,
  [SMALL_STATE(299)] = 6919,
  [SMALL_STATE(300)] = 6929,
  [SMALL_STATE(301)] = 6937,
  [SMALL_STATE(302)] = 6947,
  [SMALL_STATE(303)] = 6957,
  [SMALL_STATE(304)] = 6965,
  [SMALL_STATE(305)] = 6973,
  [SMALL_STATE(306)] = 6981,
  [SMALL_STATE(307)] = 6989,
  [SMALL_STATE(308)] = 6997,
  [SMALL_STATE(309)] = 7005,
  [SMALL_STATE(310)] = 7013,
  [SMALL_STATE(311)] = 7021,
  [SMALL_STATE(312)] = 7031,
  [SMALL_STATE(313)] = 7039,
  [SMALL_STATE(314)] = 7047,
  [SMALL_STATE(315)] = 7055,
  [SMALL_STATE(316)] = 7063,
  [SMALL_STATE(317)] = 7071,
  [SMALL_STATE(318)] = 7079,
  [SMALL_STATE(319)] = 7087,
  [SMALL_STATE(320)] = 7095,
  [SMALL_STATE(321)] = 7103,
  [SMALL_STATE(322)] = 7111,
  [SMALL_STATE(323)] = 7119,
  [SMALL_STATE(324)] = 7127,
  [SMALL_STATE(325)] = 7135,
  [SMALL_STATE(326)] = 7143,
  [SMALL_STATE(327)] = 7151,
  [SMALL_STATE(328)] = 7159,
  [SMALL_STATE(329)] = 7167,
  [SMALL_STATE(330)] = 7175,
  [SMALL_STATE(331)] = 7185,
  [SMALL_STATE(332)] = 7193,
  [SMALL_STATE(333)] = 7201,
  [SMALL_STATE(334)] = 7211,
  [SMALL_STATE(335)] = 7219,
  [SMALL_STATE(336)] = 7227,
  [SMALL_STATE(337)] = 7237,
  [SMALL_STATE(338)] = 7245,
  [SMALL_STATE(339)] = 7253,
  [SMALL_STATE(340)] = 7261,
  [SMALL_STATE(341)] = 7269,
  [SMALL_STATE(342)] = 7279,
  [SMALL_STATE(343)] = 7287,
  [SMALL_STATE(344)] = 7297,
  [SMALL_STATE(345)] = 7305,
  [SMALL_STATE(346)] = 7313,
  [SMALL_STATE(347)] = 7321,
  [SMALL_STATE(348)] = 7329,
  [SMALL_STATE(349)] = 7337,
  [SMALL_STATE(350)] = 7345,
  [SMALL_STATE(351)] = 7355,
  [SMALL_STATE(352)] = 7365,
  [SMALL_STATE(353)] = 7375,
  [SMALL_STATE(354)] = 7383,
  [SMALL_STATE(355)] = 7391,
  [SMALL_STATE(356)] = 7399,
  [SMALL_STATE(357)] = 7409,
  [SMALL_STATE(358)] = 7419,
  [SMALL_STATE(359)] = 7429,
  [SMALL_STATE(360)] = 7439,
  [SMALL_STATE(361)] = 7446,
  [SMALL_STATE(362)] = 7453,
  [SMALL_STATE(363)] = 7460,
  [SMALL_STATE(364)] = 7467,
  [SMALL_STATE(365)] = 7474,
  [SMALL_STATE(366)] = 7481,
  [SMALL_STATE(367)] = 7488,
  [SMALL_STATE(368)] = 7495,
  [SMALL_STATE(369)] = 7502,
  [SMALL_STATE(370)] = 7509,
  [SMALL_STATE(371)] = 7516,
  [SMALL_STATE(372)] = 7523,
  [SMALL_STATE(373)] = 7530,
  [SMALL_STATE(374)] = 7537,
  [SMALL_STATE(375)] = 7544,
  [SMALL_STATE(376)] = 7551,
  [SMALL_STATE(377)] = 7558,
  [SMALL_STATE(378)] = 7565,
  [SMALL_STATE(379)] = 7572,
  [SMALL_STATE(380)] = 7579,
  [SMALL_STATE(381)] = 7586,
  [SMALL_STATE(382)] = 7593,
  [SMALL_STATE(383)] = 7600,
  [SMALL_STATE(384)] = 7607,
  [SMALL_STATE(385)] = 7614,
  [SMALL_STATE(386)] = 7621,
  [SMALL_STATE(387)] = 7628,
  [SMALL_STATE(388)] = 7635,
  [SMALL_STATE(389)] = 7642,
  [SMALL_STATE(390)] = 7649,
  [SMALL_STATE(391)] = 7656,
  [SMALL_STATE(392)] = 7663,
  [SMALL_STATE(393)] = 7670,
  [SMALL_STATE(394)] = 7677,
  [SMALL_STATE(395)] = 7684,
  [SMALL_STATE(396)] = 7691,
  [SMALL_STATE(397)] = 7698,
  [SMALL_STATE(398)] = 7705,
  [SMALL_STATE(399)] = 7712,
  [SMALL_STATE(400)] = 7719,
  [SMALL_STATE(401)] = 7726,
  [SMALL_STATE(402)] = 7733,
  [SMALL_STATE(403)] = 7740,
  [SMALL_STATE(404)] = 7747,
  [SMALL_STATE(405)] = 7754,
  [SMALL_STATE(406)] = 7761,
  [SMALL_STATE(407)] = 7768,
  [SMALL_STATE(408)] = 7775,
  [SMALL_STATE(409)] = 7782,
  [SMALL_STATE(410)] = 7789,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [73] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__doc_or_meta, 1, 0, 12),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__doc_or_meta, 1, 0, 12),
  [77] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20),
  [81] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(79),
  [84] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(383),
  [87] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(408),
  [90] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(38),
  [93] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(410),
  [96] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(385),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference, 1, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [115] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(80),
  [118] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(12),
  [121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(12),
  [124] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(32),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0),
  [129] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 2, 0, 0), SHIFT_REPEAT(216),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_managed, 1, 0, 0),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_managed, 1, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference, 1, 0, 0),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(402),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(360),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(407),
  [347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference, 2, 0, 0),
  [351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference, 2, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0),
  [363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0), SHIFT_REPEAT(394),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 7),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 7),
  [406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc, 1, 0, 5),
  [412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc, 1, 0, 5),
  [414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 8),
  [416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 8),
  [418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 10),
  [420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 10),
  [422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 11),
  [424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 11),
  [426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 9),
  [428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 1, 0, 9),
  [430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc, 2, 0, 16),
  [432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc, 2, 0, 16),
  [434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_managed, 2, 0, 18),
  [436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_managed, 2, 0, 18),
  [438] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event, 2, 0, 0),
  [440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event, 2, 0, 0),
  [442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_meta, 2, 0, 0),
  [444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_meta, 2, 0, 0),
  [446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_model, 3, 0, 0),
  [448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_model, 3, 0, 0),
  [450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_model, 4, 0, 32),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_model, 4, 0, 32),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 4, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 4, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 2, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 2, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list, 3, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list, 3, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 4, 0, 0),
  [480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 4, 0, 0),
  [482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0), SHIFT_REPEAT(399),
  [485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_s_expression, 3, 0, 2),
  [487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_s_expression, 3, 0, 2),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_s_expression, 4, 0, 14),
  [495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_s_expression, 4, 0, 14),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(177),
  [500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(395),
  [503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(387),
  [506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(15),
  [509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(372),
  [512] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(362),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(191),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(360),
  [523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(400),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(65),
  [529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(407),
  [532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__doc_or_meta_repeat1, 2, 0, 20), SHIFT_REPEAT(384),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 46),
  [537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 46),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 6, 0, 45),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 6, 0, 45),
  [543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 7, 0, 55),
  [545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 7, 0, 55),
  [547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_binding, 5, 0, 35),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_binding, 5, 0, 35),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cond, 4, 0, 29),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cond, 4, 0, 29),
  [555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cond, 5, 0, 36),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cond, 5, 0, 36),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2, 0, 0), SHIFT_REPEAT(155),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_repeat1, 2, 0, 0),
  [566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0),
  [570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0), SHIFT(190),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [575] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0), SHIFT(95),
  [578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0), SHIFT(164),
  [581] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat1, 1, 0, 0), SHIFT(120),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0), SHIFT_REPEAT(401),
  [593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_variable, 1, 0, 34),
  [595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_variable, 1, 0, 34),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__def_name, 1, 0, 1),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__def_name, 1, 0, 1),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_cond_repeat1, 2, 0, 30),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_cond_repeat1, 2, 0, 30),
  [607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_cond_repeat1, 2, 0, 30), SHIFT_REPEAT(330),
  [610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_identifier, 1, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_identifier, 1, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_identifier, 1, 0, 38),
  [618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_identifier, 1, 0, 38),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_annotation, 2, 0, 0),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_annotation, 2, 0, 0),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parametrized_list, 3, 0, 56),
  [626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parametrized_list, 3, 0, 56),
  [628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parametrized_object, 3, 0, 56),
  [630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parametrized_object, 3, 0, 56),
  [632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parametrized_object, 4, 0, 60),
  [634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parametrized_object, 4, 0, 60),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reference_repeat1, 2, 0, 0), SHIFT_REPEAT(380),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_repeat1, 2, 0, 0), SHIFT_REPEAT(213),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interface_repeat1, 2, 0, 0),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_variable, 2, 0, 44),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_variable, 2, 0, 44),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_cond_repeat1, 4, 0, 47),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_cond_repeat1, 4, 0, 47),
  [680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_managed, 3, 0, 24),
  [690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_managed, 3, 0, 24),
  [692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [696] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(214),
  [699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(352),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_model_repeat1, 2, 0, 0),
  [723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_model_repeat1, 2, 0, 0), SHIFT_REPEAT(271),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_defpact_repeat1, 2, 0, 0), SHIFT_REPEAT(284),
  [739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_defpact_repeat1, 2, 0, 0),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [765] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0), SHIFT_REPEAT(356),
  [768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_let_binding_repeat1, 2, 0, 0),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_field, 1, 0, 31),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 37),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_field_list, 1, 0, 0),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [801] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_schema_field_list_repeat1, 2, 0, 0), SHIFT_REPEAT(241),
  [804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_schema_field_list_repeat1, 2, 0, 0),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use, 5, 0, 15),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use, 4, 0, 4),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use, 6, 0, 23),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_repeat2, 2, 0, 0),
  [846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_repeat2, 2, 0, 0), SHIFT_REPEAT(60),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0), SHIFT_REPEAT(217),
  [856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_repeat1, 2, 0, 0),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defproperty, 5, 0, 39),
  [862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace, 4, 0, 3),
  [864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defconst, 5, 0, 21),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 5, 0, 39),
  [874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__property_name, 1, 0, 13),
  [876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__property_name, 1, 0, 13),
  [878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_schema_field, 2, 0, 40),
  [880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defschema, 5, 0, 41),
  [882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bless, 4, 0, 42),
  [884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements, 4, 0, 43),
  [886] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 4, 0, 6),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 48),
  [892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 5, 0, 19),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 6, 0, 49),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 6, 0, 50),
  [902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 6, 0, 51),
  [904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 6, 0, 49),
  [906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 5, 0, 21),
  [908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 6, 0, 50),
  [910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 6, 0, 51),
  [912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defconst, 6, 0, 52),
  [914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 6, 0, 49),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 5, 0, 22),
  [920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 6, 0, 50),
  [922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 6, 0, 51),
  [924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defschema, 6, 0, 53),
  [926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 7, 0, 33),
  [928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defproperty, 4, 0, 6),
  [930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_bind_pair, 4, 0, 54),
  [932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface, 6, 0, 25),
  [934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 5, 0, 39),
  [936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 7, 0, 57),
  [938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 7, 0, 58),
  [940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 7, 0, 59),
  [942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 7, 0, 57),
  [944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 7, 0, 58),
  [946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 7, 0, 59),
  [948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 7, 0, 57),
  [950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 6, 0, 26),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 7, 0, 58),
  [954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 6, 0, 27),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 7, 0, 59),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defproperty, 5, 0, 21),
  [962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 8, 0, 61),
  [964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defcap, 8, 0, 61),
  [966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defpact, 8, 0, 61),
  [968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_step, 4, 0, 62),
  [970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defproperty, 6, 0, 51),
  [972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_step, 5, 0, 63),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_step_with_rollback, 5, 0, 64),
  [976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_deftable, 8, 0, 65),
  [978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_step_with_rollback, 6, 0, 66),
  [980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_deftable, 9, 0, 67),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pair, 3, 0, 28),
  [986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defun, 5, 0, 39),
  [988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bind_pair, 3, 0, 28),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1068] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_pact(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_atom,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
